///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Author: JT Cook - http://www.avalondreams.com
//
// Last Modified: x.x.xx
//
// Description: Zelda style demo
//
// PC binary build: gcc xgs_wrapper2.c ziel.c `sdl-config --cflags --libs` -o ziel
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//#define PC_SIM 
#define XGS_CONSOLE 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// INCLUDES
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#ifdef PC_SIM
#include "xgs_wrapper2.h" //for PC Dev
#endif

#ifdef XGS_CONSOLE
// Include main system header
#include "XGS_PIC_SYSTEM_V010.h"

// Include graphics drivers
#include "JTC_NTSC_GFX_DRV_v003.h"
#include "JTC_NTSC_240_192_v003.h"

// Include the gamepad driver
#include "XGS_PIC_GAMEPAD_DRV_V010.h"
#endif 

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// DEFINES
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
#define font_offset 1 //where the font tiles starts
#define font_start 33 //where in the ascii chart the font starts

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// GLOBALS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

Sprite g_Sprites[MAX_SPRITES];					// Max sprites

#define Scroll_Delay 3

#define World_Map_X 2
#define World_Map_Y 2
//map is only 2x2
unsigned char world_map[] __attribute__((far))=
{
 0,1,
 2,3,
};

//15x12 map for 16x16 tiles
unsigned char map_16x16[] __attribute__((far))=
{
  //map 1
 16,16,16,16,16,16,20,16,21,16,16,16,16,16,16,
 21,16,16,16,16,16,20,16,20, 0, 0, 0, 0, 0, 0,
 20,16,16,16,16,16,20,16,25, 0, 0, 0, 6, 0, 0,
 20,16,16,16,16,16,25, 0, 0, 0, 0, 0, 0, 0, 0,
 20, 0, 0, 0, 0, 0, 0, 5, 5, 5, 5, 0, 0, 0, 0,
 20, 0, 0, 0, 0, 0, 0, 5, 5, 5, 5, 5, 5, 5, 0,
 20, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 5, 5,
 20, 0, 0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
 20, 0, 0, 3, 4, 0, 0, 0, 0, 0, 8,12,12,12,12,
 20, 0, 0, 0, 6, 0, 0, 0, 0, 0,14, 7, 7, 7, 7,
 20, 0, 0, 0, 0, 0, 0, 0, 0, 6,14, 7, 7, 7, 7,
 20, 6, 0, 0, 0, 0, 0, 0, 0, 0,14, 7, 7, 7, 7,
  //map 2
 16,16,16,16,16,16,16,16,16,16,15, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0,15, 0, 0, 0, 0,
  0, 0, 0, 1, 2, 0, 0, 0, 0, 0,15, 0, 0, 0, 0,
  0, 0, 0, 3, 4, 0, 0, 0, 0, 0,27,12,12,12,12,
  0, 0, 0, 0, 0, 0, 0, 0, 6, 0,19,16,16,16,16,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0,19,16,16,16,16,
  5, 5, 5, 5, 5, 5, 5, 0, 0, 0,19,16,16,16,16,
  0, 0, 0, 0, 0, 0, 5, 0, 0, 0,26,16,22,16,16,
 12,12, 9, 0, 0, 0, 5, 0, 0, 0, 0, 0,19,16,16,
  7, 7,15, 0, 0, 0, 5, 0, 0, 0, 0, 0,19,16,16,
  7, 7,15, 0, 0, 0, 5, 0, 0, 6, 0, 0,19,16,16,
  7, 7,15, 0, 0, 0, 5, 0, 0, 0, 0, 0,19,16,16,
  //map 3
 20, 0, 0, 0, 0, 0, 0, 0, 0, 0,14, 7, 7, 7, 7,
 18, 0, 0, 0, 0, 0, 0, 0, 0, 0,14, 7, 7, 7, 7,
  0, 0, 0, 0, 1, 2, 0, 0, 0, 0,10,13,13,13,13,
  0, 0, 0, 0, 3, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 5, 5, 0, 0, 6, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 5, 5, 5, 5, 5, 5, 5, 5, 5,
 12,12,12,12,12,12,12, 9, 0, 0, 0, 0, 0, 0, 0,
  7, 7, 7, 7, 7, 7, 7,15, 0, 0, 0, 0, 0, 0, 0,
  7, 7, 7, 7, 7, 7, 7,24,12,12, 9, 0, 1, 2, 1,
  7, 7, 7, 7, 7, 7, 7, 7, 7, 7,15, 1, 2, 1, 2,
  //map 4
  7, 7,15, 0, 0, 0, 5, 0, 0, 0, 0, 0,19,16,16,
  7, 7,15, 0, 0, 0, 5, 0, 0, 0, 0, 0,17,16,16,
 13,13,11, 1, 2, 0, 5, 0, 0, 0, 0, 0, 6, 0, 0,
  0, 0, 0, 3, 4, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 5, 0, 6, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0,
  5, 5, 5, 5, 5, 5, 5, 0, 0, 0, 0, 0, 0, 0, 0,
  0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8,12,12,12,12,
  0, 0, 1, 2, 1, 2, 0, 0, 0, 0,14, 7, 7, 7, 7,
  2, 1, 2, 1, 2, 4, 8,12,12,12,23, 7, 7, 7, 7,
  1, 2, 1, 2, 1, 2,14, 7, 7, 7, 7, 7, 7, 7, 7,

};

//4 8x8 tiles combined into a 16x16 tile
unsigned char tile_16x16[] __attribute__((far))=
{
//0 -grass
1,1,1,1,
//1- tree, upper left
4,5,6,7,
//2- tree, upper right
8,9,10,11,
//3- tree lower left
12,13,14,15,
//4- tree lower right
16,17,18,19,
//5- rock path
20,21,22,23,
//6- grass with leaves
0,1,2,3,
//7- water
24,25,26,27,
//8- rock upper left corner
30,28,29,42,
//9- rock upper right corner
28,31,43,29,
//10- rock lower left corner
29,44,32,28,
//11- rock lower right corner
45,29,28,33,
//12- rock vertical with wall top
28,28,40,41,
//13- rock vertical with wall bottom
34,35,28,28,
//14 - horizontl rock with wall left
29,38,29,39,
//15 - horizontl rock with wall right
37,29,36,29,
//16 - rock as wall/mountain
40,41,40,41,
//17 - lower left corner with rock and grass
46,41,48,41,
//18 - lower right corner with rock and grass
40,47,40,49,
//19 - wall left side
46,41,46,41,
//20 - wall right side
40,47,40,47,
//21 - wall corner lower left side
40,41,40,42,
//22 - wall right lower right side
40,41,43,41,
//23 - rock odd angel lower left
51,38,40,44,
//24 - rock odd angel lower right
36,50,45,41,
//25 - rock odd angel lower left w/ grass
40,47,40,49,
//26 - rock odd angel lower right w/ grass
46,41,48,41,
//27 - rock lower left corner
36,50,46,41,

};

//how many wall tiles there are
#define max_wall_tiles 24
//tell which 16x16 tiles are designated as a wall
unsigned char wall_tiles[] =
{
 1,2,3,4,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26
};

//sprite data
unsigned char g_SpriteData[] __attribute__((far))=
{
//Sprite number:0
0x0,0x0,0x0,0x0,0x0,0x4F,0x52,0x52,0x52,0x52,0x4F,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x4F,0x52,0x52,0x52,0x52,0x52,0x52,0x4F,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x4F,0x52,0xE3,0x52,0x52,0x52,0x52,0x4F,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x4F,0xE3,0x4F,0xE3,0x52,0x4F,0xE3,0x4F,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x4F,0x4F,0xE3,0x4F,0xE3,0xE3,0x4F,0xE3,0x4F,0x4F,0x0,0x0,0x0,
0x0,0x0,0x4F,0xAF,0xAF,0x8F,0xE3,0xE3,0xE3,0xE3,0x8F,0xAF,0xAF,0x4F,0x0,0x0,
0x0,0x4F,0xAF,0xBF,0xBF,0xAF,0x8F,0x8F,0x8F,0x8F,0xAF,0xBF,0xBF,0xAF,0x4F,0x0,
0x0,0x4F,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0x8F,0x4F,0x0,
0x0,0x4F,0xBF,0xAF,0x8F,0xAF,0xBF,0xBF,0xBF,0xBF,0xBF,0x9F,0x8F,0xE3,0x4F,0x0,
0x0,0x4F,0xBF,0xBF,0x9F,0x8F,0xAF,0xBF,0xBF,0xBF,0xAF,0x8F,0xE3,0x4F,0x0,0x0,
0x0,0x0,0x4F,0x9F,0xE3,0xE3,0x8F,0x8F,0x8F,0x8F,0x8F,0x4F,0x4F,0x0,0x0,0x0,
0x0,0x0,0x0,0x4F,0xE3,0xE3,0x9F,0xBF,0xBF,0xBF,0x9F,0x4F,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x4F,0x8F,0x8F,0x9F,0xBF,0xBF,0xAF,0x4F,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x4F,0x52,0x52,0x4F,0x8F,0x8F,0x8F,0x4F,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x4F,0x4F,0x4F,0x4F,0x4F,0x52,0x52,0x52,0x4F,0x4F,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x0,0x0,0x0,0x0,
//Sprite number:1
0x0,0x0,0x0,0x0,0x0,0x4F,0x52,0x52,0x52,0x52,0x4F,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x4F,0x52,0x52,0x52,0x52,0x52,0x52,0x4F,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x4F,0x52,0xE3,0x52,0x52,0x52,0x52,0x4F,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x4F,0xE3,0x4F,0xE3,0x52,0x4F,0xE3,0x4F,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x4F,0x4F,0xE3,0x4F,0xE3,0xE3,0x4F,0xE3,0x4F,0x4F,0x0,0x0,0x0,
0x0,0x0,0x4F,0xAF,0xAF,0x8F,0xE3,0xE3,0xE3,0xE3,0x8F,0xAF,0xAF,0x4F,0x0,0x0,
0x0,0x4F,0xAF,0xBF,0xBF,0xAF,0x8F,0x8F,0x8F,0x8F,0xAF,0xBF,0xBF,0xAF,0x4F,0x0,
0x0,0x4F,0x8F,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0x4F,0x0,
0x0,0x4F,0xE3,0x8F,0x9F,0xBF,0xBF,0xBF,0xBF,0xBF,0xAF,0x8F,0xAF,0xBF,0x4F,0x0,
0x0,0x0,0x4F,0xE3,0x8F,0xAF,0xBF,0xBF,0xBF,0xAF,0x8F,0x9F,0xBF,0xBF,0x4F,0x0,
0x0,0x0,0x0,0x4F,0x4F,0x8F,0x8F,0x8F,0x8F,0x8F,0xE3,0xE3,0x9F,0x4F,0x0,0x0,
0x0,0x0,0x0,0x0,0x4F,0x9F,0xBF,0xBF,0xBF,0x9F,0xE3,0xE3,0x4F,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x4F,0xAF,0xBF,0xBF,0x9F,0x8F,0x8F,0x4F,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x4F,0x8F,0x8F,0x8F,0x4F,0x52,0x52,0x4F,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x4F,0x4F,0x52,0x52,0x52,0x4F,0x4F,0x4F,0x4F,0x4F,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x0,0x0,0x0,0x0,0x0,
};

// The TILE map buffer must be allocated into far memory space because 
// it is so large it wont fit into near 
unsigned char g_TileMap[SCREEN_TILE_MAP_WIDTH*SCREEN_TILE_MAP_HEIGHT] __attribute__((far));

// Character set as 8x8 with 1 byte per pixel
//unsigned char g_TileData[((8*8)*12)*16] __attribute__((far));
unsigned char g_TileData[] __attribute__((far))= {
//Tile number:0
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
0x70,0x70,0x50,0x70,0x70,0x70,0x70,0x70,
0x70,0x50,0x50,0x70,0x70,0x70,0x70,0x70,
0x50,0x50,0x50,0x70,0x70,0x50,0x50,0x70,
0x50,0x50,0x50,0x50,0x50,0x50,0x70,0x70,
0x70,0x70,0x50,0x50,0x50,0x70,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
//Tile number:1
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
//Tile number:2
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
//Tile number:3
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x50,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x50,0x50,0x70,
0x70,0x50,0x50,0x70,0x70,0x50,0x50,0x50,
0x70,0x70,0x50,0x50,0x50,0x50,0x50,0x50,
0x70,0x70,0x70,0x50,0x50,0x50,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
//Tile number:4
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x70,0x4F,0x4F,
0x70,0x70,0x70,0x70,0x70,0x4F,0x50,0x70,
0x70,0x70,0x70,0x70,0x4F,0x4F,0x4F,0x50,
0x70,0x70,0x70,0x4F,0x50,0x70,0x70,0x70,
0x70,0x70,0x4F,0x50,0x70,0x70,0x70,0x50,
0x70,0x4F,0x50,0x70,0x70,0x70,0x70,0x50,
0x4F,0x4F,0x50,0x70,0x70,0x70,0x70,0x50,
//Tile number:5
0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,
0x4F,0x40,0x70,0x70,0x70,0x70,0x40,0x4F,
0x70,0x70,0x70,0x40,0x40,0x40,0x40,0x70,
0x70,0x40,0x40,0x40,0x70,0x70,0x70,0x70,
0x40,0x40,0x40,0x70,0x70,0x70,0x70,0x70,
0x40,0x40,0x70,0x70,0x70,0x70,0x70,0x70,
0x40,0x40,0x70,0x70,0x70,0x70,0x70,0x70,
0x40,0x40,0x70,0x70,0x70,0x70,0x70,0x70,
//Tile number:6
0x4F,0x40,0x40,0x70,0x70,0x70,0x70,0x40,
0x4F,0x40,0x40,0x70,0x70,0x70,0x70,0x70,
0x4F,0x40,0x40,0x40,0x70,0x70,0x70,0x70,
0x4F,0x4F,0x40,0x40,0x70,0x70,0x70,0x70,
0x4F,0x4F,0x40,0x40,0x40,0x70,0x40,0x70,
0x70,0x4F,0x40,0x4F,0x40,0x40,0x40,0x70,
0x4F,0x4F,0x4F,0x4F,0x40,0x40,0x40,0x40,
0x4F,0x40,0x4F,0x4F,0x40,0x40,0x4F,0x40,
//Tile number:7
0x40,0x40,0x40,0x70,0x70,0x70,0x40,0x40,
0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
0x70,0x70,0x70,0x40,0x40,0x70,0x70,0x40,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
0x70,0x40,0x70,0x70,0x70,0x40,0x70,0x70,
0x40,0x40,0x40,0x70,0x40,0x40,0x70,0x70,
//Tile number:8
0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,
0x4F,0x4F,0x40,0x70,0x70,0x70,0x70,0x40,
0x70,0x40,0x40,0x40,0x40,0x40,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x40,0x40,0x40,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x40,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x40,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x40,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x40,
//Tile number:9
0x4F,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
0x4F,0x4F,0x4F,0x70,0x70,0x70,0x70,0x70,
0x70,0x70,0x40,0x4F,0x70,0x70,0x70,0x70,
0x70,0x40,0x4F,0x4F,0x4F,0x4F,0x70,0x70,
0x40,0x70,0x70,0x70,0x40,0x4F,0x4F,0x70,
0x40,0x70,0x70,0x70,0x70,0x40,0x4F,0x70,
0x40,0x40,0x70,0x70,0x70,0x70,0x4F,0x4F,
0x40,0x40,0x70,0x70,0x70,0x70,0x40,0x4F,
//Tile number:10
0x70,0x70,0x70,0x70,0x70,0x70,0x40,0x40,
0x40,0x70,0x70,0x70,0x40,0x40,0x40,0x40,
0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
0x40,0x40,0x40,0x70,0x70,0x40,0x70,0x70,
0x40,0x40,0x70,0x70,0x70,0x70,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x40,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x40,0x40,0x70,
0x70,0x40,0x70,0x70,0x40,0x40,0x40,0x40,
//Tile number:11
0x40,0x70,0x70,0x70,0x70,0x70,0x40,0x4F,
0x40,0x70,0x70,0x70,0x70,0x40,0x40,0x4F,
0x70,0x70,0x70,0x70,0x70,0x40,0x40,0x4F,
0x70,0x70,0x40,0x70,0x70,0x40,0x4F,0x4F,
0x70,0x70,0x40,0x70,0x40,0x40,0x4F,0x4F,
0x70,0x40,0x40,0x40,0x4F,0x40,0x4F,0x70,
0x70,0x40,0x40,0x40,0x4F,0x4F,0x4F,0x4F,
0x40,0x40,0x40,0x40,0x4F,0x4F,0x40,0x4F,
//Tile number:12
0x4F,0x40,0x40,0x4F,0x4F,0x40,0x4F,0x40,
0x4F,0x40,0x40,0x40,0x4F,0x4F,0x4F,0x40,
0x4F,0x4F,0x40,0x40,0x40,0x40,0x4F,0x4F,
0x70,0x4F,0x40,0x4F,0x40,0x40,0x40,0x4F,
0x4F,0x4F,0x4F,0x4F,0x40,0x40,0x40,0x40,
0x4F,0x51,0x4F,0x4F,0x4F,0x40,0x40,0x40,
0x4F,0x51,0x51,0x51,0x4F,0x4F,0x40,0x40,
0x4F,0x4F,0x51,0x51,0x4F,0x4F,0x4F,0x4F,
//Tile number:13
0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x70,
0x40,0x40,0x40,0x4F,0x40,0x40,0x40,0x40,
0x40,0x40,0x40,0x4F,0x40,0x40,0x40,0x40,
0x4F,0x4F,0x4F,0x4F,0x4F,0x40,0x40,0x40,
0x40,0x40,0x40,0x40,0x4F,0x4F,0x4F,0x4F,
0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
0x4F,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
0x4F,0x4F,0x4F,0x40,0x40,0x40,0x4F,0x4F,
//Tile number:14
0x50,0x4F,0x4F,0x41,0x4F,0x51,0x61,0x51,
0x50,0x50,0x50,0x4F,0x51,0x61,0x61,0x61,
0x70,0x50,0x4F,0x41,0x61,0x61,0x61,0x51,
0x70,0x50,0x4F,0x51,0x61,0x51,0x51,0x41,
0x70,0x70,0x4F,0x41,0x51,0x41,0x4F,0x4F,
0x70,0x70,0x50,0x4F,0x4F,0x4F,0x50,0x50,
0x70,0x70,0x70,0x70,0x70,0x70,0x50,0x50,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
//Tile number:15
0x51,0x41,0x41,0x41,0x4F,0x4F,0x4F,0x4F,
0x51,0x51,0x51,0x51,0x51,0x51,0x41,0x41,
0x51,0x41,0x4F,0x41,0x51,0x61,0x61,0x61,
0x4F,0x4F,0x4F,0x4F,0x41,0x61,0x61,0x61,
0x4F,0x50,0x50,0x4F,0x41,0x51,0x61,0x61,
0x50,0x50,0x50,0x50,0x4F,0x41,0x51,0x51,
0x50,0x50,0x50,0x50,0x50,0x4F,0x4F,0x51,
0x70,0x50,0x50,0x50,0x50,0x50,0x4F,0x4F,
//Tile number:16
0x70,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
0x40,0x40,0x40,0x40,0x40,0x40,0x4F,0x40,
0x40,0x4F,0x40,0x40,0x40,0x40,0x4F,0x40,
0x4F,0x4F,0x4F,0x40,0x40,0x4F,0x4F,0x4F,
0x4F,0x40,0x4F,0x4F,0x4F,0x4F,0x40,0x40,
0x40,0x40,0x40,0x40,0x40,0x40,0x40,0x40,
0x40,0x40,0x40,0x40,0x40,0x4F,0x40,0x40,
0x4F,0x40,0x40,0x40,0x4F,0x4F,0x4F,0x4F,
//Tile number:17
0x40,0x4F,0x40,0x4F,0x4F,0x40,0x40,0x4F,
0x40,0x4F,0x4F,0x4F,0x40,0x40,0x40,0x4F,
0x4F,0x4F,0x40,0x40,0x40,0x40,0x4F,0x4F,
0x4F,0x40,0x40,0x40,0x4F,0x40,0x4F,0x51,
0x40,0x40,0x40,0x40,0x4F,0x4F,0x4F,0x4F,
0x40,0x40,0x40,0x4F,0x4F,0x4F,0x51,0x4F,
0x40,0x40,0x4F,0x4F,0x51,0x51,0x51,0x4F,
0x4F,0x4F,0x4F,0x4F,0x51,0x51,0x4F,0x4F,
//Tile number:18
0x41,0x4F,0x4F,0x4F,0x4F,0x41,0x41,0x41,
0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x51,
0x61,0x51,0x41,0x41,0x41,0x4F,0x41,0x41,
0x61,0x51,0x41,0x41,0x4F,0x4F,0x4F,0x4F,
0x51,0x51,0x41,0x41,0x4F,0x50,0x50,0x4F,
0x51,0x41,0x41,0x4F,0x4F,0x50,0x50,0x50,
0x41,0x4F,0x4F,0x4F,0x50,0x50,0x50,0x50,
0x4F,0x4F,0x50,0x50,0x50,0x50,0x50,0x50,
//Tile number:19
0x51,0x51,0x41,0x4F,0x41,0x41,0x4F,0x50,
0x51,0x61,0x51,0x41,0x4F,0x4F,0x50,0x50,
0x51,0x51,0x61,0x51,0x41,0x4F,0x50,0x50,
0x41,0x51,0x51,0x51,0x51,0x4F,0x50,0x50,
0x4F,0x4F,0x41,0x51,0x41,0x4F,0x50,0x50,
0x50,0x4F,0x4F,0x4F,0x4F,0x50,0x50,0x70,
0x50,0x50,0x50,0x50,0x50,0x50,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
//Tile number:20
0x70,0xBF,0xBF,0xBF,0xBF,0xBF,0x70,0x70,
0xBF,0xBF,0xBF,0x9F,0xBF,0xBF,0xBF,0x70,
0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0x70,
0xBF,0x9F,0xBF,0xBF,0x9F,0xBF,0x9F,0x70,
0x9F,0xBF,0xBF,0x9F,0xBF,0xBF,0x9F,0x70,
0x50,0x9F,0x9F,0x50,0x9F,0x9F,0x50,0x70,
0x70,0x50,0x50,0x70,0x50,0x50,0x70,0x70,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
//Tile number:21
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
0x70,0xBF,0xBF,0x70,0xBF,0xBF,0x70,0x70,
0xBF,0xBF,0x9F,0xBF,0xBF,0xBF,0xBF,0x70,
0xBF,0xBF,0xBF,0xBF,0xBF,0x9F,0xBF,0x70,
0xBF,0xBF,0x9F,0xBF,0xBF,0xBF,0x9F,0x70,
0x9F,0xBF,0xBF,0xBF,0xBF,0xBF,0x9F,0x70,
0x50,0x9F,0x9F,0x9F,0x9F,0x9F,0x50,0x70,
0x70,0x50,0x50,0x50,0x50,0x50,0x70,0x70,
//Tile number:22
0x70,0x70,0xBF,0xBF,0xBF,0xBF,0xBF,0x70,
0x70,0xBF,0xBF,0xBF,0x9F,0xBF,0xBF,0xBF,
0x70,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,
0x70,0x9F,0xBF,0x9F,0xBF,0xBF,0x9F,0xBF,
0x70,0x9F,0xBF,0xBF,0x9F,0xBF,0xBF,0x9F,
0x70,0x50,0x9F,0x9F,0x50,0x9F,0x9F,0x50,
0x70,0x70,0x50,0x50,0x70,0x50,0x50,0x70,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
//Tile number:23
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
0x70,0x70,0xBF,0xBF,0x70,0xBF,0xBF,0x70,
0x70,0xBF,0xBF,0x9F,0xBF,0xBF,0xBF,0xBF,
0x70,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,0xBF,
0x70,0xBF,0x9F,0xBF,0xBF,0x9F,0xBF,0x9F,
0x70,0x9F,0xBF,0xBF,0xBF,0xBF,0xBF,0x9F,
0x70,0x50,0x9F,0x9F,0x9F,0x9F,0x9F,0x50,
0x70,0x70,0x50,0x50,0x50,0x50,0x50,0x70,
//Tile number:24
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
//Tile number:25
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
//Tile number:26
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
//Tile number:27
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,0x9D,
//Tile number:28
0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,
0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x41,
0x61,0x61,0x61,0x61,0x61,0x61,0x61,0x61,
0x71,0x61,0x71,0x71,0x71,0x71,0x71,0x71,
0x71,0x71,0x71,0x71,0x71,0x61,0x71,0x71,
0x61,0x61,0x41,0x61,0x61,0x41,0x61,0x61,
0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x41,
0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,
//Tile number:29
0x4F,0x41,0x61,0x71,0x71,0x61,0x41,0x4F,
0x4F,0x41,0x61,0x61,0x71,0x41,0x41,0x4F,
0x4F,0x41,0x61,0x71,0x71,0x61,0x41,0x4F,
0x4F,0x41,0x61,0x71,0x71,0x61,0x41,0x4F,
0x4F,0x41,0x61,0x71,0x71,0x61,0x41,0x4F,
0x4F,0x41,0x61,0x71,0x61,0x61,0x41,0x4F,
0x4F,0x41,0x61,0x71,0x71,0x41,0x41,0x4F,
0x4F,0x41,0x61,0x71,0x71,0x61,0x41,0x4F,
//Tile number:30
0x70,0x70,0x70,0x70,0x50,0x4F,0x4F,0x4F,
0x70,0x70,0x50,0x4F,0x4F,0x41,0x41,0x41,
0x70,0x50,0x4F,0x41,0x41,0x61,0x61,0x61,
0x70,0x4F,0x41,0x41,0x61,0x61,0x71,0x71,
0x50,0x4F,0x41,0x61,0x71,0x71,0x71,0x71,
0x4F,0x41,0x61,0x71,0x71,0x71,0x71,0x61,
0x4F,0x41,0x61,0x71,0x71,0x71,0x41,0x41,
0x4F,0x41,0x41,0x71,0x71,0x61,0x41,0x4F,
//Tile number:31
0x4F,0x4F,0x4F,0x50,0x70,0x70,0x70,0x70,
0x41,0x41,0x41,0x4F,0x4F,0x50,0x70,0x70,
0x61,0x61,0x61,0x41,0x41,0x4F,0x50,0x70,
0x71,0x71,0x61,0x61,0x41,0x41,0x4F,0x70,
0x71,0x71,0x71,0x71,0x61,0x41,0x4F,0x50,
0x61,0x71,0x71,0x71,0x71,0x61,0x41,0x4F,
0x41,0x41,0x71,0x71,0x71,0x61,0x41,0x4F,
0x4F,0x41,0x61,0x71,0x71,0x41,0x41,0x4F,
//Tile number:32
0x4F,0x41,0x41,0x71,0x71,0x61,0x41,0x4F,
0x4F,0x41,0x61,0x71,0x71,0x71,0x41,0x41,
0x4F,0x41,0x61,0x71,0x71,0x71,0x71,0x61,
0x50,0x4F,0x41,0x61,0x71,0x71,0x71,0x71,
0x70,0x4F,0x41,0x41,0x61,0x61,0x71,0x71,
0x70,0x50,0x4F,0x41,0x41,0x61,0x61,0x61,
0x70,0x70,0x50,0x4F,0x4F,0x41,0x41,0x41,
0x70,0x70,0x70,0x70,0x50,0x4F,0x4F,0x4F,
//Tile number:33
0x4F,0x41,0x61,0x71,0x71,0x41,0x41,0x4F,
0x41,0x41,0x71,0x71,0x71,0x61,0x41,0x4F,
0x61,0x71,0x71,0x71,0x71,0x61,0x41,0x4F,
0x71,0x71,0x71,0x71,0x61,0x41,0x4F,0x50,
0x71,0x71,0x61,0x61,0x41,0x41,0x4F,0x70,
0x61,0x61,0x61,0x41,0x41,0x4F,0x50,0x70,
0x41,0x41,0x41,0x4F,0x4F,0x50,0x70,0x70,
0x4F,0x4F,0x4F,0x50,0x70,0x70,0x70,0x70,
//Tile number:34
0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,
0x4F,0x4F,0x4F,0x41,0x41,0x41,0x41,0x41,
0x41,0x41,0x41,0x41,0x51,0x41,0x41,0x41,
0x41,0x41,0x41,0x41,0x4F,0x41,0x41,0x41,
0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x41,
0x41,0x41,0x41,0x41,0x41,0x51,0x51,0x51,
0x41,0x41,0x41,0x51,0x51,0x51,0x51,0x51,
0x51,0x51,0x51,0x51,0x51,0x41,0x41,0x41,
//Tile number:35
0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,
0x41,0x41,0x41,0x41,0x41,0x4F,0x4F,0x4F,
0x41,0x41,0x4F,0x41,0x41,0x41,0x41,0x41,
0x41,0x41,0x41,0x41,0x41,0x51,0x51,0x41,
0x41,0x41,0x41,0x41,0x41,0x4F,0x4F,0x41,
0x51,0x51,0x51,0x41,0x41,0x4F,0x4F,0x41,
0x51,0x51,0x51,0x51,0x51,0x41,0x41,0x41,
0x41,0x41,0x41,0x51,0x51,0x51,0x51,0x51,
//Tile number:36
0x4F,0x4F,0x41,0x41,0x41,0x41,0x51,0x51,
0x4F,0x4F,0x41,0x41,0x41,0x41,0x51,0x51,
0x4F,0x4F,0x41,0x41,0x41,0x41,0x41,0x51,
0x4F,0x4F,0x41,0x41,0x41,0x41,0x41,0x51,
0x4F,0x4F,0x41,0x41,0x4F,0x41,0x41,0x51,
0x4F,0x4F,0x4F,0x41,0x41,0x41,0x51,0x51,
0x4F,0x4F,0x4F,0x41,0x41,0x41,0x51,0x51,
0x4F,0x4F,0x4F,0x41,0x41,0x41,0x51,0x51,
//Tile number:37
0x4F,0x4F,0x4F,0x41,0x41,0x41,0x51,0x51,
0x4F,0x4F,0x4F,0x41,0x41,0x41,0x51,0x51,
0x4F,0x4F,0x4F,0x41,0x41,0x41,0x51,0x51,
0x4F,0x4F,0x41,0x41,0x41,0x41,0x41,0x51,
0x4F,0x4F,0x41,0x41,0x41,0x41,0x41,0x51,
0x4F,0x4F,0x41,0x41,0x41,0x41,0x41,0x51,
0x4F,0x4F,0x41,0x4F,0x41,0x41,0x51,0x51,
0x4F,0x4F,0x41,0x41,0x41,0x41,0x51,0x51,
//Tile number:38
0x51,0x51,0x41,0x41,0x41,0x41,0x4F,0x4F,
0x51,0x51,0x41,0x41,0x41,0x41,0x4F,0x4F,
0x51,0x41,0x41,0x41,0x41,0x41,0x4F,0x4F,
0x51,0x41,0x41,0x41,0x41,0x41,0x4F,0x4F,
0x51,0x41,0x41,0x4F,0x41,0x41,0x4F,0x4F,
0x51,0x51,0x41,0x41,0x41,0x4F,0x4F,0x4F,
0x51,0x51,0x41,0x41,0x41,0x4F,0x4F,0x4F,
0x51,0x51,0x41,0x41,0x41,0x4F,0x4F,0x4F,
//Tile number:39
0x51,0x51,0x41,0x41,0x41,0x4F,0x4F,0x4F,
0x51,0x51,0x41,0x41,0x41,0x4F,0x4F,0x4F,
0x51,0x51,0x41,0x41,0x41,0x4F,0x4F,0x4F,
0x51,0x41,0x41,0x41,0x41,0x41,0x4F,0x4F,
0x51,0x41,0x41,0x41,0x41,0x41,0x4F,0x4F,
0x51,0x41,0x41,0x41,0x41,0x41,0x4F,0x4F,
0x51,0x51,0x41,0x41,0x4F,0x41,0x4F,0x4F,
0x51,0x51,0x41,0x41,0x41,0x41,0x4F,0x4F,
//Tile number:40
0x51,0x51,0x51,0x51,0x51,0x41,0x41,0x41,
0x41,0x41,0x41,0x51,0x51,0x51,0x51,0x51,
0x41,0x41,0x41,0x41,0x41,0x51,0x51,0x51,
0x41,0x41,0x41,0x41,0x41,0x41,0x41,0x41,
0x41,0x41,0x41,0x41,0x4F,0x41,0x41,0x41,
0x41,0x41,0x41,0x41,0x51,0x41,0x41,0x41,
0x4F,0x4F,0x4F,0x41,0x41,0x41,0x41,0x41,
0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,
//Tile number:41
0x41,0x41,0x41,0x51,0x51,0x51,0x51,0x51,
0x51,0x51,0x51,0x51,0x51,0x41,0x41,0x41,
0x51,0x51,0x51,0x41,0x41,0x4F,0x4F,0x41,
0x41,0x41,0x41,0x41,0x41,0x4F,0x4F,0x41,
0x41,0x41,0x41,0x41,0x41,0x51,0x51,0x41,
0x41,0x41,0x4F,0x41,0x41,0x41,0x41,0x41,
0x41,0x41,0x41,0x41,0x41,0x4F,0x4F,0x4F,
0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,
//Tile number:42
0x41,0x51,0x51,0x51,0x51,0x51,0x51,0x51,
0x51,0x51,0x51,0x51,0x51,0x51,0x51,0x51,
0x51,0x51,0x51,0x41,0x41,0x41,0x41,0x41,
0x51,0x51,0x4F,0x41,0x41,0x41,0x41,0x41,
0x51,0x51,0x4F,0x4F,0x41,0x41,0x41,0x41,
0x51,0x51,0x41,0x4F,0x4F,0x4F,0x41,0x41,
0x51,0x51,0x41,0x41,0x4F,0x4F,0x4F,0x4F,
0x51,0x51,0x41,0x41,0x41,0x4F,0x4F,0x4F,
//Tile number:43
0x51,0x51,0x51,0x51,0x51,0x51,0x51,0x41,
0x51,0x51,0x51,0x51,0x51,0x51,0x51,0x51,
0x41,0x41,0x41,0x41,0x41,0x51,0x51,0x51,
0x41,0x41,0x41,0x41,0x41,0x4F,0x51,0x51,
0x41,0x41,0x41,0x41,0x4F,0x4F,0x51,0x51,
0x41,0x41,0x4F,0x4F,0x4F,0x41,0x51,0x51,
0x4F,0x4F,0x4F,0x4F,0x41,0x41,0x51,0x51,
0x4F,0x4F,0x4F,0x41,0x41,0x41,0x51,0x51,
//Tile number:44
0x51,0x51,0x41,0x41,0x41,0x4F,0x4F,0x4F,
0x51,0x51,0x41,0x41,0x4F,0x4F,0x4F,0x4F,
0x51,0x51,0x41,0x4F,0x4F,0x4F,0x41,0x41,
0x51,0x51,0x4F,0x4F,0x41,0x41,0x41,0x41,
0x51,0x51,0x4F,0x41,0x41,0x41,0x41,0x41,
0x51,0x51,0x51,0x41,0x41,0x41,0x41,0x41,
0x51,0x51,0x51,0x51,0x51,0x51,0x51,0x51,
0x41,0x51,0x51,0x51,0x51,0x51,0x51,0x51,
//Tile number:45
0x4F,0x4F,0x4F,0x41,0x41,0x41,0x51,0x51,
0x4F,0x4F,0x4F,0x4F,0x41,0x41,0x51,0x51,
0x41,0x41,0x4F,0x4F,0x4F,0x41,0x51,0x51,
0x41,0x41,0x41,0x41,0x4F,0x4F,0x51,0x51,
0x41,0x41,0x41,0x41,0x41,0x4F,0x51,0x51,
0x41,0x41,0x41,0x41,0x41,0x51,0x51,0x51,
0x51,0x51,0x51,0x51,0x51,0x51,0x51,0x51,
0x51,0x51,0x51,0x51,0x51,0x51,0x51,0x41,
//Tile number:46
0x4F,0x4F,0x41,0x41,0x41,0x41,0x41,0x51,
0x4F,0x4F,0x4F,0x41,0x41,0x41,0x41,0x41,
0x4F,0x4F,0x4F,0x41,0x41,0x41,0x41,0x41,
0x4F,0x4F,0x41,0x4F,0x41,0x41,0x41,0x41,
0x4F,0x4F,0x51,0x41,0x4F,0x41,0x41,0x41,
0x4F,0x4F,0x51,0x51,0x41,0x4F,0x4F,0x41,
0x4F,0x4F,0x41,0x51,0x51,0x41,0x4F,0x4F,
0x4F,0x4F,0x41,0x41,0x51,0x51,0x51,0x41,
//Tile number:47
0x51,0x41,0x41,0x41,0x41,0x41,0x4F,0x4F,
0x41,0x41,0x41,0x41,0x41,0x4F,0x4F,0x4F,
0x41,0x41,0x41,0x41,0x41,0x4F,0x4F,0x4F,
0x41,0x41,0x41,0x41,0x4F,0x41,0x4F,0x4F,
0x41,0x41,0x41,0x4F,0x41,0x51,0x4F,0x4F,
0x41,0x4F,0x4F,0x41,0x51,0x51,0x4F,0x4F,
0x4F,0x4F,0x41,0x51,0x51,0x41,0x4F,0x4F,
0x41,0x51,0x51,0x51,0x41,0x41,0x4F,0x4F,
//Tile number:48
0x4F,0x4F,0x41,0x41,0x41,0x41,0x41,0x51,
0x4F,0x4F,0x41,0x41,0x41,0x41,0x41,0x41,
0x70,0x4F,0x4F,0x41,0x41,0x41,0x41,0x41,
0x70,0x70,0x4F,0x41,0x41,0x41,0x41,0x41,
0x70,0x70,0x70,0x4F,0x41,0x41,0x41,0x41,
0x70,0x70,0x70,0x70,0x4F,0x4F,0x41,0x41,
0x70,0x70,0x70,0x70,0x70,0x4F,0x4F,0x4F,
0x70,0x70,0x70,0x70,0x70,0x70,0x70,0x4F,
//Tile number:49
0x51,0x41,0x41,0x41,0x41,0x41,0x4F,0x4F,
0x41,0x41,0x41,0x41,0x41,0x41,0x4F,0x4F,
0x41,0x41,0x41,0x41,0x41,0x4F,0x4F,0x70,
0x41,0x41,0x41,0x41,0x41,0x4F,0x70,0x70,
0x41,0x41,0x41,0x41,0x4F,0x70,0x70,0x70,
0x41,0x41,0x4F,0x4F,0x70,0x70,0x70,0x70,
0x4F,0x4F,0x4F,0x70,0x70,0x70,0x70,0x70,
0x4F,0x70,0x70,0x70,0x70,0x70,0x70,0x70,
//Tile number:50
0x4F,0x41,0x61,0x71,0x71,0x61,0x41,0x4F,
0x4F,0x41,0x71,0x71,0x71,0x61,0x61,0x41,
0x4F,0x41,0x61,0x71,0x71,0x71,0x61,0x61,
0x4F,0x41,0x61,0x71,0x71,0x71,0x71,0x71,
0x4F,0x41,0x41,0x61,0x71,0x71,0x71,0x71,
0x4F,0x4F,0x41,0x41,0x61,0x61,0x61,0x61,
0x4F,0x4F,0x4F,0x41,0x41,0x41,0x41,0x41,
0x51,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,
//Tile number:51
0x4F,0x41,0x61,0x71,0x71,0x61,0x41,0x4F,
0x41,0x61,0x61,0x71,0x71,0x71,0x41,0x4F,
0x61,0x61,0x71,0x71,0x71,0x61,0x41,0x4F,
0x71,0x71,0x71,0x71,0x71,0x61,0x41,0x4F,
0x71,0x71,0x71,0x71,0x61,0x41,0x41,0x4F,
0x61,0x61,0x61,0x61,0x41,0x41,0x4F,0x4F,
0x41,0x41,0x41,0x41,0x41,0x4F,0x4F,0x4F,
0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x51,
//Tile number:52
0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,
0x41,0x41,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,
0x51,0x4F,0x51,0x4F,0x51,0x4F,0x61,0x61,
0x61,0x4F,0x4F,0x4F,0x41,0x4F,0x4F,0x4F,
0x61,0x61,0x61,0x61,0x4F,0x61,0x41,0x61,
0x41,0x41,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,
0x41,0x4F,0x51,0x4F,0x51,0x4F,0x61,0x61,
0x4F,0x4F,0x4F,0x4F,0x41,0x4F,0x4F,0x4F,
//Tile number:53
0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,
0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x41,0x41,
0x61,0x61,0x4F,0x51,0x4F,0x51,0x4F,0x51,
0x4F,0x4F,0x4F,0x41,0x4F,0x4F,0x4F,0x61,
0x61,0x41,0x61,0x4F,0x61,0x61,0x61,0x61,
0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x41,0x41,
0x61,0x61,0x4F,0x51,0x4F,0x51,0x4F,0x41,
0x4F,0x4F,0x4F,0x41,0x4F,0x4F,0x4F,0x4F,
//Tile number:54
0x41,0x41,0x41,0x51,0x4F,0x51,0x51,0x51,
0x51,0x51,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,
0x51,0x4F,0x51,0x4F,0x51,0x4F,0x61,0x61,
0x41,0x4F,0x4F,0x4F,0x41,0x4F,0x4F,0x4F,
0x41,0x41,0x4F,0x41,0x4F,0x41,0x41,0x41,
0x41,0x41,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,
0x41,0x4F,0x51,0x4F,0x51,0x4F,0x61,0x61,
0x4F,0x4F,0x4F,0x4F,0x41,0x4F,0x4F,0x4F,
//Tile number:55
0x51,0x51,0x51,0x4F,0x51,0x41,0x41,0x41,
0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x51,0x51,
0x61,0x61,0x4F,0x51,0x4F,0x51,0x4F,0x51,
0x4F,0x4F,0x4F,0x41,0x4F,0x4F,0x4F,0x41,
0x41,0x41,0x41,0x4F,0x41,0x4F,0x41,0x41,
0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x41,0x41,
0x61,0x61,0x4F,0x51,0x4F,0x51,0x4F,0x41,
0x4F,0x4F,0x4F,0x41,0x4F,0x4F,0x4F,0x4F,
//Tile number:56
0x70,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,
0x4F,0x4F,0x41,0x41,0x41,0x41,0x41,0x41,
0x4F,0x41,0x41,0x61,0x61,0x61,0x61,0x61,
0x4F,0x41,0x61,0x71,0x71,0x71,0x71,0x71,
0x4F,0x41,0x61,0x71,0x71,0x71,0x71,0x71,
0x4F,0x4F,0x41,0x61,0x61,0x61,0x61,0x61,
0x4F,0x4F,0x4F,0x41,0x41,0x41,0x41,0x41,
0x51,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,
//Tile number:57
0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x70,
0x41,0x41,0x41,0x41,0x41,0x41,0x4F,0x4F,
0x61,0x61,0x61,0x61,0x61,0x41,0x41,0x4F,
0x71,0x71,0x71,0x71,0x71,0x61,0x41,0x4F,
0x71,0x71,0x71,0x71,0x71,0x61,0x41,0x4F,
0x61,0x61,0x61,0x61,0x61,0x41,0x4F,0x4F,
0x41,0x41,0x41,0x41,0x41,0x4F,0x4F,0x4F,
0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x4F,0x51,
};

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// FUNCTIONS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void print_string(int x, int y, char *string);
void DrawTile16x16(int tilex, int tiley, int tile);
void DrawMap16x16(int Map_number);
int Check_hit(int x,int y, int dir);
void DrawNewMap(int Map_Direction);
void In_Game();
void Scroll_Screen();
unsigned char GamepadValue, GamepadValueOld, x_old, y_old, direction, diagnal=0;
unsigned char object_frame=0, animation_counter=0;
unsigned char MapX=0, MapY=0, Current_Map; //world map location
int room_offset; //for collision detection to grab the correct room
unsigned char GameState; //state of game (ie: menu, game play, scrolling, etc)
unsigned char Scroll_direction, Scroll_Counter, Scroll_Counter2; //for screen scrolling/transition
// Our main start location
#ifdef XGS_CONSOLE
int main (void)
#endif
#ifdef PC_SIM
void main_init ()
#endif
{

	int i;
	// Always call ConfigureClock first
	SYS_ConfigureClock(FCY_NTSC);

	// Init the gamepad
	Gamepad_Init();

	// Init the graphics system
    GFX_InitTile(g_TileData, g_TileMap, g_Sprites);

    fill_screen(0); //clears the screen
     
    //move all sprites off screen
    for(i=0;i<8;i++)
    {
		g_Sprites[i].X = 0;
		g_Sprites[i].Y = 0;
    }

	// setup sprite info
	g_Sprites[0].X = 50;
	g_Sprites[0].Y = 100;

	g_Sprites[0].PixelData = g_SpriteData;
	
	// Start up our display interrupt
	GFX_StartDrawing(SCREEN_TYPE_NTSC);
	//setup the map
	DrawNewMap(0);
        x_old=g_Sprites[0].X;
        y_old=g_Sprites[0].Y;
	//jump into the gameplay
	GameState=1; 
#ifdef XGS_CONSOLE
        main_loop();
	return(0);
#endif
}

void main_loop()
{
#ifdef XGS_CONSOLE
  while(1)
#endif 
  {
	// Wait until we are in v-sync to do any processing
	WAIT_FOR_VSYNC_START();

	switch(GameState)
	{
		//main game
		case 1:
			In_Game();
		break;
		//scrolling screen when moving to a new screen
		case 2:
			Scroll_Screen();
		break;
	};
	// Wait here till we are done with v-sync
	WAIT_FOR_VSYNC_END();

  }
}

//screen scrolling / transition
void Scroll_Screen()
{
 int z=0, i2=0, i, mx, my;
 unsigned char temp_tile_buffer[30], temp_tile;
 int map_offset;
 //Scroll_direction - 1-Left, 2-Right, 3-Up, 4-Down
 //30x24 for tile map, 15x12 map


 //scroll the map right (left border)
 if(Scroll_direction==1)
 {
  Scroll_Counter2--;
  if(Scroll_Counter2<1)
  {
    Scroll_Counter--;   
    Scroll_Counter2=Scroll_Delay;
    //grab sliver from new map
    map_offset=Current_Map*(15*12);
    for(i=0;i<12;i++)
    {    
      temp_tile=map_16x16[(15*i)+((Scroll_Counter-2)>>1)+map_offset];
      temp_tile<<=2; //multiply by 4 since tiles are 4 bytes
      temp_tile_buffer[i2]=tile_16x16[temp_tile+((Scroll_Counter)&1)];
      i2++;
      temp_tile_buffer[i2]=tile_16x16[temp_tile+2+((Scroll_Counter)&1)];
      i2++;
    }
    //scroll map
    if(Scroll_Counter>1)
    {
      z=30;
      for(my=0;my<24;my++)
      {
       for(mx=0;mx<29;mx++)
       {
          z--;
	  g_TileMap[z]=g_TileMap[z-1];
       }
       //z--;
       g_TileMap[--z]=temp_tile_buffer[my];
         
       z+=60;
      }
      //move sprite with map
      g_Sprites[0].X+=8;
    }
    //finish scrolling the map
    else
     GameState=1;
  }
 }
 //scroll the map left (hit the right border)
 else if(Scroll_direction==2)
 {
  Scroll_Counter2--;
  if(Scroll_Counter2<1)
  {
    Scroll_Counter--;   
    Scroll_Counter2=Scroll_Delay;
    //grab sliver from new map
    map_offset=Current_Map*(15*12);
    for(i=0;i<12;i++)
    {    
      temp_tile=map_16x16[(15*i)+(15-(Scroll_Counter>>1))+map_offset];
      temp_tile<<=2; //multiply by 4 since tiles are 4 bytes
      temp_tile_buffer[i2]=tile_16x16[temp_tile+((Scroll_Counter-1)&1)];
      i2++;
      temp_tile_buffer[i2]=tile_16x16[temp_tile+2+((Scroll_Counter-1)&1)];
      i2++;
    }
    z=0;
    //scroll map
    if(Scroll_Counter>1)
    {
      for(my=0;my<24;my++)
      {
       for(mx=0;mx<29;mx++)
       {
	  g_TileMap[z]=g_TileMap[z+1];
          z++;
       }
       g_TileMap[z]=temp_tile_buffer[my];
       z++;
      }
      //move sprite with map
      g_Sprites[0].X-=8;
    }
    //finish scrolling the map
    else
     GameState=1;
  }
 } 
//scroll the map down (top border)
 else if(Scroll_direction==3)
 {
  Scroll_Counter2--;
  if(Scroll_Counter2<1)
  {
    Scroll_Counter--;   
    Scroll_Counter2=Scroll_Delay;
    //grab sliver from new map
    map_offset=Current_Map*(15*12);
    for(i=0;i<15;i++)
    {    
      temp_tile=map_16x16[(((Scroll_Counter-2)>>1)*15)+i+map_offset];
      temp_tile<<=2; //multiply by 4 since tiles are 4 bytes
      temp_tile_buffer[i2]=tile_16x16[(temp_tile)+((Scroll_Counter&1)<<1)];
      i2++;
      temp_tile_buffer[i2]=tile_16x16[(temp_tile+1)+((Scroll_Counter&1)<<1)];
      i2++;
    }
    z=30*24-30;
    //scroll map
    if(Scroll_Counter>1)
    {
      for(my=0;my<23;my++)
      {
       for(mx=0;mx<30;mx++)
       {
	  g_TileMap[z]=g_TileMap[z-30];
          z++;
       }
       z-=60;
      }
      for(mx=0;mx<30;mx++)
      {
	g_TileMap[mx]=temp_tile_buffer[mx];
      }
      //move sprite with map
      g_Sprites[0].Y+=8;
    }
    //finish scrolling the map
    else
     GameState=1;
  }
 }
//scroll the map up (bottom border)
 else if(Scroll_direction==4)
 {
  Scroll_Counter2--;
  if(Scroll_Counter2<1)
  {
    Scroll_Counter--;   
    Scroll_Counter2=Scroll_Delay;
    //grab sliver from new map
    map_offset=Current_Map*(15*12);
    for(i=0;i<15;i++)
    {    
      temp_tile=map_16x16[(((24-Scroll_Counter+1)>>1)*15)+i+map_offset];
      temp_tile<<=2; //multiply by 4 since tiles are 4 bytes
      temp_tile_buffer[i2]=tile_16x16[(temp_tile)+((Scroll_Counter+1&1)<<1)];
      i2++;
      temp_tile_buffer[i2]=tile_16x16[(temp_tile+1)+((Scroll_Counter+1&1)<<1)];
      i2++;
    }
    z=0;
    //scroll map
    if(Scroll_Counter>1)
    {
      for(my=0;my<23;my++)
      {
       for(mx=0;mx<30;mx++)
       {
	  g_TileMap[z]=g_TileMap[z+30];
          z++;
       }
      }
      int my=30*23;
      for(mx=0;mx<30;mx++)
      {
	g_TileMap[mx+my]=temp_tile_buffer[mx];
      }
      //move sprite with map
      g_Sprites[0].Y-=8;
    }
    //finish scrolling the map
    else
     GameState=1;
  }
 }
 
}

//main gameplay
void In_Game()
{
    int i=0;
	{
		// Read the gamepad
		GamepadValue = Gamepad_Read(0);		
		// player controls
		//diagnals first
		if(GamepadValue & GAMEPAD_UP && GamepadValue & GAMEPAD_LEFT)
		{
                		animation_counter++;
			    diagnal^=1;
				if(diagnal==0)
				{
					direction=0;
  					g_Sprites[0].Y--;
				}
				else
				{
					direction=2;
					g_Sprites[0].X--;
				}
		}
		else if(GamepadValue & GAMEPAD_UP && GamepadValue & GAMEPAD_RIGHT)
		{
                		animation_counter++;
			    diagnal^=1;
				if(diagnal==0)
				{
					direction=0;
  					g_Sprites[0].Y--;
				}
				else
				{
					direction=3;
					g_Sprites[0].X++;
				}

		}
		else if(GamepadValue & GAMEPAD_DOWN && GamepadValue & GAMEPAD_LEFT)
		{
                		animation_counter++;
			    diagnal^=1;
				if(diagnal==0)
				{
					direction=1;
  					g_Sprites[0].Y++;
				}
				else
				{
					direction=2;
					g_Sprites[0].X--;
				}

		}
		else if(GamepadValue & GAMEPAD_DOWN && GamepadValue & GAMEPAD_RIGHT)
		{
                		animation_counter++;
			    diagnal^=1;
				if(diagnal==0)
				{
					direction=1;
  					g_Sprites[0].Y++;
				}
				else
				{
					direction=3;
					g_Sprites[0].X++;
				}
		}
		//standard up down left right
		else if(GamepadValue & GAMEPAD_UP)
		{
				g_Sprites[0].Y--;
				direction=0;
                		animation_counter++;
		}
		else if(GamepadValue & GAMEPAD_DOWN)
		{
				g_Sprites[0].Y++;
				direction=1;
                		animation_counter++;
		}
		else if(GamepadValue & GAMEPAD_LEFT)
		{
				g_Sprites[0].X--;
				direction=2;
	                animation_counter++;
		}
		else if(GamepadValue & GAMEPAD_RIGHT)
		{
				g_Sprites[0].X++;
				direction=3;
 	                animation_counter++;
		}


		//handle animation
		if(animation_counter>9)
		{
			animation_counter=0;
			object_frame^=1; //toggle new frame
            //grab new graphic  
			g_Sprites[0].PixelData = g_SpriteData + (object_frame<<8);
		}
	    //check collision detection
		//both dots hit the wall
	        i=Check_hit(g_Sprites[0].X & 0xFF,g_Sprites[0].Y & 0xFF,direction);
                if(i==1)
		{
			g_Sprites[0].X=x_old;
			g_Sprites[0].Y=y_old;	
		}

		//1st dot hit the wall only, move right
		else if(i==2)
		{
		  //up/down - move right
		  if(direction==0 || direction==1)
		  {
			g_Sprites[0].Y=y_old;
			g_Sprites[0].X+=1;	
		  }
		  //left/right - move down
		  if(direction==2 || direction==3)
		  {
			g_Sprites[0].Y+=1;
			g_Sprites[0].X=x_old;	
		  }

		}
		//2nd dot hit the wall only, move left
		else if(i==3)
		{
		  //up/down - move left
		  if(direction==0 || direction==1)
		  {
			g_Sprites[0].Y=y_old;
			g_Sprites[0].X-=1;
		  }
		  //left/right - move up
		  if(direction==2 || direction==3)
		  {
			g_Sprites[0].Y-=1;
			g_Sprites[0].X=x_old;	
		  }

		}
 		//0x10-left, 0x20-right, 0x30-up, 0x40-down
		else if(i==0x10) //move map left
		{
			g_Sprites[0].X-=4;
			DrawNewMap(i>>4);
		}
		else if(i==0x20) //move map right
		{
			g_Sprites[0].X+=4;
			DrawNewMap(i>>4);
		}
		else if(i==0x30) //move map up
		{
			g_Sprites[0].Y-=4;
			DrawNewMap(i>>4);
		}
		else if(i==0x40) //move map down
		{
			g_Sprites[0].Y+=4;
			DrawNewMap(i>>4);
		}

	        GamepadValueOld = GamepadValue; 	        
		x_old=g_Sprites[0].X;
		y_old=g_Sprites[0].Y;
	}

}
//check collision against background
int Check_hit(int x,int y, int dir)
{
 //idea is to check two dots infront of the direction the object is moving
 int n, tile, wall=0;
 int x1,x2, y1,y2;
 //setup the limits for the screen

 if(x<16)
 {
  if(x<8) //check to see if we load a new map
    return 0x10; //left
  else
    x=16;
 }
 else if(x>240)
 {
  if(x>248) //check to see if we load a new map
    return 0x20; //right
  else
    x=240;
 }
 else if(y<16)
 {
  if(y<8) //check to see if we load a new map
    return 0x30; //up
  else
    y=16;  
 }
 else if(y>192)
 {
  if(y>200) //check to see if we load a new map
    return 0x40; //down
  else
  y=192;
 }
 x=(x-16)&0xFF;
 y=(y-16)&0xFF;

 x1=x;
 y1=y;
 x2=x;
 y2=y;
 
 //direction 0=up, 1=down, 2=left, 3=right
 switch(dir)
 {
  //up
  case 0: 
  {
   x1+=2;
   x2+=13;
  }
  break;
  //down
  case 1:
  {
   x1+=2;
   x2+=13;
   y1+=15;
   y2+=15;
  }
  break;
  //left
  case 2:
  {
   y1+=2;
   y2+=13;
  }
  break;
  //right
  case 3:
  {
   y1+=2;
   y2+=13;
   x1+=15;
   x2+=15;
  }
  break;
 }
 //check dot 1
 x1>>=4; //x/=16
 y1>>=4; //y/=16
 n=y1*15+x1;
 tile=map_16x16[n+room_offset];
 //go through all the wall tiles
 for(n=0;n<max_wall_tiles;n++)
 {
   //if we match a wall tile, then return it
   if(wall_tiles[n] == tile)
     wall|=1;
 }

 //check dot 2
 x2>>=4; //x/=16
 y2>>=4; //y/=16
 n=y2*15+x2;
 tile=map_16x16[n+room_offset];

 for(n=0;n<max_wall_tiles;n++)
 {
   //if we match a wall tile, then return it
   if(wall_tiles[n] == tile)
	wall|=2;
 }
 if(wall==0)
   return(0);
 if(wall==3)
   return(1);
 if(wall==1)
   return(2);
 if(wall==2)
   return(3);
}



//////////////////////////////////////////////////////////////
// Draw a 16x16 tile
void DrawTile16x16(int tilex, int tiley, int tile)
{
 //where we will draw tile
 int offset=(tiley*2)*30+(tilex*2);
 //multiply tile value by 4
 tile<<=2;
 g_TileMap[offset]=tile_16x16[tile++];
 g_TileMap[offset+1]=tile_16x16[tile++]; 
 offset+=30;
 g_TileMap[offset]=tile_16x16[tile++]; 
 g_TileMap[offset+1]=tile_16x16[tile]; 

}
//////////////////////////////////////////////////////////////
// Draw a map using 16x16 tiles
void DrawMap16x16(int Map_number)
{
  //maps are 15x12
  int mapx, mapy, n;
  n=(15*12)*Map_number;
  for(mapy=0;mapy<12;mapy++)
  {
     for(mapx=0;mapx<15;mapx++)
     {
	DrawTile16x16(mapx,mapy,map_16x16[n]);
//	DrawTile16x16(mapx,mapy,0);
	n++;
     }
  }
}
//////////////////////////////////////////////////////////////
// Draw new map from world map
void DrawNewMap(int Map_Direction)
{
//First select direction we are moving in
//0-redraw current map, 1-left, 2-right, 3-up, 4-down
    if(Map_Direction==1) //left
    {
    	MapX--;
    	if(MapX>=World_Map_X)
       		MapX=World_Map_X-1;
    }
    else if(Map_Direction==2) //right
    {
    	MapX++;
    	if(MapX>=World_Map_X)
       		MapX=0;
    }
    else if(Map_Direction==3) //up
    {
    	MapY--;
    	if(MapY>=World_Map_Y)
       		MapY=World_Map_Y-1;
    }
    else if(Map_Direction==4) //down
    {
    	MapY++;
    	if(MapY>=World_Map_Y)
       		MapY=0;
    }
    room_offset=world_map[MapY*World_Map_X+MapX]; 
    //draw the new map
    Current_Map=room_offset;
    if(Map_Direction==0) //no scrolling
    	DrawMap16x16(room_offset);
    Scroll_direction=Map_Direction; //direction to scroll screen
    //scrolling screen left or right
    if(Map_Direction==1 || Map_Direction==2)
    {
      Scroll_Counter=32; //used for scrolling
      GameState=2; //scroll screen
    }
    if(Map_Direction==3 || Map_Direction==4)
    {
      Scroll_Counter=26; //used for scrolling
      GameState=2; //scroll screen
    }

    Scroll_Counter2=Scroll_Delay; //used for delay in scrolling
    room_offset*=(15*12); // grab the offset for collision detection
}

//////////////////////////////////////////////////////////////
//screen helpers

//prints a string
void print_string(int x, int y, char *string)
{
 int n, offset, screen_ctr;
 offset=font_offset-font_start;
 screen_ctr=y*SCREEN_TILE_MAP_WIDTH+x;
 for(n=0;n<50;n++)
 {
   //make sure we are only printing characters that we have graphics for
   if(string[n]>32 && string[n]<91)
    g_TileMap[screen_ctr]=string[n]+offset; //draw digit
   else if(string[n]==0)
    return;
   screen_ctr++;
 }

}

