rem ------------------------------------------------------
rem A pong clone in XGS Basic
rem Created by Josh Hintze
rem Compatabile with XGS Basic v1.2
rem Copyright 2009 Nurve Networks LLC.
rem ------------------------------------------------------

rem Set the target as bitmap (not tile)
option target = "bitmap"

rem ------------------------------------------------------

dim ballx
dim bally
dim dirx
dim diry
dim player1_paddle
dim cpu_paddle
dim cpu_hesitation

dim sound_counter

dim game_paused
dim player_score
dim cpu_score
dim cpu_rand_hit_loc

def ball_width = 3
def ball_height = 4
def paddle_height = 15
def paddle_speed = 3

rem Gamepad direction defines
def gp_right  = 0x01
def gp_left   = 0x02
def gp_down   = 0x04
def gp_up     = 0x08
def gp_start  = 0x10
def gp_select = 0x20
def gp_red    = 0x40
def gp_yellow = 0x80

rem ------------------------------------------------------
rem Draws the playfield except for the middle line
rem ------------------------------------------------------

sub UpdateBall
    rem Erase the ball
    call fillrect(ballx, bally, ball_width, ball_height, 0)
       
    rem Update the X and Y positions   
    ballx = ballx + dirx
    if ballx <= 11 then
        rem Check for the paddle collision
        if(bally < (player1_paddle - 5)) | (bally > (player1_paddle + paddle_height + 5)) then
            rem MISS
            ballx = 60
            bally = rnd(170) + 20
            game_paused = 1
            dirx = 2
            diry = -2 + rnd(4)            
            cpu_score = cpu_score + 1
        else
            rem HIT
            dirx = 2
            call sound(500)
            sound_counter = 15
            cpu_hesitation = 30
            
            rem update y direction based on ball hit location
            if(bally < player1_paddle + paddle_height/2 - 3) then
                diry = -2
            else if(bally > player1_paddle + paddle_height/2 + 3) then    
                diry = 2
            else
                diry = 0
            end if
            
        end if
    else if ballx >= 148 then
        rem Check for the paddle collision with cpu
        if(bally < (cpu_paddle - 5)) | (bally > (cpu_paddle + paddle_height + 5)) then
            rem MISS
            ballx = 100
            bally = rnd(170) + 20
            game_paused = 1
            dirx = -2
            diry = -2 + rnd(4)       
            player_score = player_score + 1
        else
            rem HIT
            dirx = -2
            call sound(700)
            sound_counter = 15
            cpu_hesitation = 20
            cpu_rand_hit_loc = rnd(15)
            
            rem update y direction based on ball hit location
            if(bally < cpu_paddle + paddle_height/2 - 3) then
                diry = -2
            else if(bally > cpu_paddle + paddle_height/2 + 3) then    
                diry = 2
            else
                diry = 0
            end if

        end if
    end if
    
    bally = bally + diry
    if bally > 191 then
        bally = 191
        diry = -2
    else if bally < 0 then
        bally = 0
        diry = 2
    end if
    
    
    rem Draw the ball
    call fillrect(ballx, bally, ball_width, ball_height, 1)
    
end sub

rem ------------------------------------------------------


rem ------------------------------------------------------
rem Checks gamepad for input and moves the paddles
rem ------------------------------------------------------

sub UpdatePaddles

    rem Erase the previous paddles
    call vline(10, player1_paddle, player1_paddle + paddle_height, 0)
    call vline(150, cpu_paddle, cpu_paddle + paddle_height, 0)

    rem Check for player input
    buttons = gamepad(0)
    if(buttons & gp_up) then
        player1_paddle = player1_paddle - paddle_speed
    else if(buttons & gp_down) then
        player1_paddle = player1_paddle + paddle_speed
    end if
    
    rem Check paddle limits paddle 1
    if(player1_paddle < 0) then
        player1_paddle = 0
    end if
    
    if(player1_paddle > 191 - paddle_height) then
        player1_paddle = 191 - paddle_height
    end if
    
    rem Computer AI 
    cpu_dy = 0
    
    if(cpu_hesitation > 0) then
        cpu_hesitation = cpu_hesitation - 1
    else     
        rem Check ball direction    
        if(dirx < 0) then
            rem Ball is traveling away so mirror the players movements
            if(player1_paddle < cpu_paddle) then
                cpu_dy = -1
            else if(player1_paddle > cpu_paddle) then
                cpu_dy = 1
            end if
        else
            rem Ball is traveling towards our paddle
            if(bally < cpu_paddle + cpu_rand_hit_loc) then
                cpu_dy = -2
            else if(bally > cpu_paddle + cpu_rand_hit_loc) then
                cpu_dy = 2
            end if
        end if
    end if    
    
    
    cpu_paddle = cpu_paddle + cpu_dy
    
    rem Check paddle limits cpu paddle
    if(cpu_paddle < 0) then
        cpu_paddle = 0
    end if

    if(cpu_paddle > 191 - paddle_height) then
        cpu_paddle = 191 - paddle_height
    end if
        

    rem Now draw the paddles
    call vline(10, player1_paddle, player1_paddle + paddle_height, 3)
    call vline(150, cpu_paddle, cpu_paddle + paddle_height, 3)


end sub

rem ------------------------------------------------------
rem Displays the score up to 5, then winner at 5
rem ------------------------------------------------------

sub DisplayScore
         
    rem Clear previous score
    call text(65, 5, " ")
    call text(85, 5, " ")    
    
    rem Draw the player_score
    if(player_score = 0) then
        call text(65, 5, "0")
    else if(player_score = 1) then
        call text(65, 5, "1")
    else if(player_score = 2) then
        call text(65, 5, "2")       
    else if(player_score = 3) then
        call text(65, 5, "3")       
    else if(player_score = 4) then
        call text(65, 5, "4")               
    else
        call text(65, 5, "5")       
        rem Display winner loser
        call text(20,20, "winner")
        call text(120,20, "loser")
    end if
    
    rem Draw the cpu_score
    if(cpu_score = 0) then
        call text(85, 5, "0")
    else if(cpu_score = 1) then
        call text(85, 5, "1")
    else if(cpu_score = 2) then
        call text(85, 5, "2")       
    else if(cpu_score = 3) then
        call text(85, 5, "3")       
    else if(cpu_score = 4) then
        call text(85, 5, "4")               
    else 
        call text(85, 5, "5")       
        rem Display winner loser
        call text(20,20, "loser")
        call text(120,20, "winner")
    end if
    

end sub



rem ------------------------------------------------------
rem Main Code
rem ------------------------------------------------------

do
    rem ------Initialize------
    ballx = 70
    bally = 96
    dirx = 2
    diry = 2
    player1_paddle = 76
    cpu_paddle = 76
    game_paused = 1
    cpu_hesitation = 0
    player_score = 0
    cpu_score = 0
    cpu_rand_hit_loc = rnd(15)
    
    rem ------Title Screen------
    call clear(0)
    call vline(0, 0, 191, 3)
    call vline(159, 0, 191, 3)
    call hline(0, 159, 0, 3)
    call hline(0, 159, 191, 3)
    call text(55,20, "XGS PONG josh")
    call text(20,40, "Powered by XGS BASIC")
    call text(20,160, "Press Start to Play")
    
    do while not (gamepad(0) & gp_start)

    loop
    
    call clear(0)

    rem ------Game Loop------
    do
    
        rem Wait for vsync to update display
        call waitforvsync()
     
        rem Update the ball position
        call UpdateBall()

        rem Redraw the vertical divider line
        call vline(80, 0, 191, 0)
        vline_starty = 0
        for i = 0 to 32
            call vline(80, vline_starty, vline_starty+3, 2)
            vline_starty = vline_starty + 6
        next i

        rem Update the paddle positions based on gamepads
        call UpdatePaddles()

        rem Show scores
        call DisplayScore()
        call DisplayScore()

        rem Check for sound playing
        if (sound_counter <> 0) then
            sound_counter = sound_counter - 1
            if(sound_counter = 0) then
                call sound(0)
            end if
        end if
        
        rem See if game is paused
        do while (game_paused)
            if(gamepad(0) & gp_yellow) then
                game_paused = 0
                if (player_score = 5) | (cpu_score = 5) then
                    player_score = 0
                    cpu_score = 0
                    player1_paddle = 76
                    cpu_paddle = 76
                    call clear(0)
                end if

            end if
        loop
        
    
    loop

loop

rem ------------------------------------------------------
