///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Author: JT Cook - http://www.avalondreams.com
//
// Last Modified: x.x.xx
//
// Description: Pacman
//
// Todo:
// Score
// death animation
// in game text (game over, ready, score)
// power pellets (so you can eat ghosts)
// fix color issues (void Menu() and ghosts)
//
// Note:  Safe LUMA values are 4-A
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
//#define PC_SIM 
#define XGS_CONSOLE 
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// INCLUDES
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#include <stdio.h>
#include <stdlib.h>
#include <string.h>


#ifdef PC_SIM
#include "xgs_wrapper2.h" //for PC Dev
#endif

#ifdef XGS_CONSOLE
// Include main system header
#include "XGS_PIC_SYSTEM_V010.h"

// Include graphics drivers
#include "JTC_NTSC_GFX_DRV_v004.h"
#include "JTC_NTSC_240_192_v004.h"

// Include the gamepad driver
#include "XGS_PIC_GAMEPAD_DRV_V010.h"
#endif 

#include "pac_gfx_01.h" //graphics
#include "font1bit.h" //1 bit font
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// DEFINES
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
#define font_offset 1 //where the font tiles starts
#define font_start 48 //where in the ascii chart the font starts
// Generates a random integer between x and y inclusive
#define RAND_RANGE(x,y) ( ( x ) + (rand()%( ( y ) - ( x )+1)))
#define Maze_Color 0x4C
#define White_Maze 0xAF
#define New_Maze_Color 0x7C
#define font_color 0xAF
#define font_bg 0x4F
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// GLOBALS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

Sprite g_Sprites[MAX_SPRITES];					// Max sprites

// The TILE map buffer must be allocated into far memory space because 
// it is so large it wont fit into near 
MapScroll g_Map[2];  //Map scrolling info
unsigned char g_TileMap[SCREEN_TILE_MAP_WIDTH*SCREEN_TILE_MAP_HEIGHT] __attribute__((far)) = {};
unsigned char g_SpriteData[256*8] __attribute__((far)); //sprites from g_PacSprites
unsigned char g_TileData[(64)*40] __attribute__((far)); //tiles
//21x24
unsigned char const pac_maze[SCREEN_TILE_MAP_WIDTH*SCREEN_TILE_MAP_HEIGHT] __attribute__((far)) = {
10,7,7,7,7,7,7,7,7,7,16,7,7,7,7,7,7,7,7,7,9,
8,1,1,1,1,1,1,1,1,1,8,1,1,1,1,1,1,1,1,1,8,
8,2,10,7,9,1,10,7,9,1,8,1,10,7,9,1,10,7,9,2,8,
8,1,11,7,12,1,11,7,12,1,6,1,11,7,12,1,11,7,12,1,8,
8,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,8,
8,1,4,7,3,1,5,1,4,7,16,7,3,1,5,1,4,7,3,1,8,
8,1,1,1,1,1,8,1,1,1,8,1,1,1,8,1,1,1,1,1,8,
11,7,7,7,9,1,15,7,3,1,6,1,4,7,14,1,10,7,7,7,12,
0,0,0,0,8,1,8,0,0,0,0,0,0,0,8,1,8,0,0,0,0,
0,0,0,0,8,1,8,0,10,7,13,7,9,0,8,1,8,0,0,0,0,
7,7,7,7,12,1,6,0,8,0,0,0,8,0,6,1,11,7,7,7,7,
0,0,0,0,0,1,0,0,8,0,0,0,8,0,0,1,0,0,0,0,0,
7,7,7,7,9,1,5,0,8,0,0,0,8,0,5,1,10,7,7,7,7,
0,0,0,0,8,1,8,0,11,7,7,7,12,0,8,1,8,0,0,0,0,
0,0,0,0,8,1,8,0,0,0,0,0,0,0,8,1,8,0,0,0,0,
10,7,7,7,12,1,6,0,4,7,16,7,3,0,6,1,11,7,7,7,9,
8,1,1,1,1,1,1,1,1,1,8,1,1,1,1,1,1,1,1,1,8,
8,1,4,7,9,1,4,7,3,1,6,1,4,7,3,1,10,7,3,1,8,
8,2,1,1,8,1,1,1,1,1,0,1,1,1,1,1,8,1,1,2,8,
15,7,3,1,6,1,5,1,4,7,16,7,3,1,5,1,6,1,4,7,14,
8,1,1,1,1,1,8,1,1,1,8,1,1,1,8,1,1,1,1,1,8,
8,1,4,7,7,7,17,7,3,1,6,1,4,7,17,7,7,7,3,1,8,
8,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,8,
11,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,12,
};

//pacman animation
unsigned char pac_animation[]={0,1,2,1,0,3,4,3,0,5,6,5,0,7,8,7};

///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// FUNCTIONS
///////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void print_string(int x, int y, char *string);
void In_Game();
int check_wall(int x, int y,int xx,int yy);
int move_pac(int p_dir);
void move_ghost(unsigned char g_number);
void reset_characters(); 
void reset_maze();
void check_dots(int x, int y);
void Beat_Level();
void change_maze(unsigned char old_color, unsigned char new_color);
void copy_font(int char_number, int char_data);
void Menu();
void intro_screen();
void copy_sprites(char *source_sprite, char *dest_sprite);
void draw_lives();
int pac_ghost_hit();
unsigned char GamepadValue, GamepadValueOld;
unsigned char GameState; //state of game (ie: menu, game play, scrolling, etc)
unsigned char pac_frame=0, pac_tic=0;
unsigned char pac_x, pac_y, pac_x_old, pac_y_old, pac_lives;
int pac_dir, pac_dir_old;
unsigned char ghost_x[4], ghost_y[4], ghost_x_old[4], ghost_y_old[4], ghost_dir[4], ghost_tic[4], ghost_frame[4], ghost_hall_ctr[4];
unsigned int total_dots, misc_timer;


// Our main start location
#ifdef XGS_CONSOLE
int main (void)
#endif
#ifdef PC_SIM
void main_init ()
#endif
{

	int i;
	// Always call ConfigureClock first
	SYS_ConfigureClock(FCY_NTSC);

	// Init the gamepad
	Gamepad_Init();

	// Init the graphics system
    GFX_InitTile(g_TileData, g_TileMap, g_Sprites, g_Map);

    fill_screen(0); //clears the screen


    //move all sprites off screen
    for(i=0;i<8;i++)
    {
		g_Sprites[i].X = 0;
		g_Sprites[i].Y = 0;
    }


	// Start up our display interrupt
	GFX_StartDrawing(SCREEN_TYPE_NTSC);
	GameState=0; 
	intro_screen();
#ifdef XGS_CONSOLE
        main_loop();
	return(0);
#endif
}


void main_loop()
{
#ifdef XGS_CONSOLE
  while(1)
#endif 
  {
	// Wait until we are in v-sync to do any processing
	WAIT_FOR_VSYNC_START();

	switch(GameState)
	{
		//intro screen
		case 0:
			Menu();
		break;
		//main game
		case 1:
			In_Game();
		break;
		//beat the level
		case 2:
			Beat_Level();
		break;
		//pause/ready right before a level
		case 3:
  		   misc_timer++;
		   if(misc_timer>120)
  		   {
		     GameState=1; 
   			 misc_timer=0;
		   }
		break;
		//pac dies
		case 4:
		   misc_timer++;
		   if(misc_timer>120)
		   {
			if(pac_lives>0)
			{	
			  pac_lives--;
			  GameState=3;
			  misc_timer=0;
			  reset_characters();		
			}
			else
			{
			  misc_timer=0;
			  GameState=5; //Game Over	
			}

                   }
		break;		
		//game over
		case 5:
		   misc_timer++;
		   if(misc_timer>120)
		   {
			  intro_screen();
			  misc_timer=0;
			  GameState=0; //Game Over	
                   }
		break;		

	};
	// Wait here till we are done with v-sync
	WAIT_FOR_VSYNC_END();

  }
}

void Menu()
{
		int i;
		GamepadValue = Gamepad_Read(0);		
		// player controls
                //right, left, up, down
		if(GamepadValue & GAMEPAD_ACTION1 | GamepadValue & GAMEPAD_ACTION2 | GamepadValue & GAMEPAD_START)
		{
                       	GameState=3;
			    //copy maze tiles
			    for(i=0;i<(64*18)-1;i++)
			    {
				   //g_TileData[i]=pac_TileData[i];

   				   if(pac_TileData[i]>0xAF)
	 			   //safe colors
     					g_TileData[i]=(pac_TileData[i]&0xF) | 0xA0;	
				   else
				      g_TileData[i]=pac_TileData[i];
			    }
			    reset_maze(); //draws the maze
    				reset_characters(); //place all the characters/sprites	
		}
		pac_x--;
		//move pac at the bottom of the screen
		g_Sprites[0].Y=pac_y-2;
 		g_Sprites[0].X=pac_x-2;
		g_Sprites[0].X&=0xFF;
		g_Sprites[0].Y&=0xFF;
		pac_tic++;
		//animate pac
		if(pac_tic>4)
		{
			pac_frame++;
			pac_frame&=3;
			//g_Sprites[0].PixelData = g_SpriteData + (9 <<8); //debug
			pac_tic=0;			
		}		
		i=(pac_animation[pac_frame+(pac_dir<<2)]);
		if(i>9)
			i=9;
                
		copy_sprites((g_PacSprites + (i<<8)), g_SpriteData);
		g_Sprites[0].PixelData = g_SpriteData;
}

//main gameplay
void In_Game()
{
    int i=0, j;
	{
		pac_dir_old=pac_dir;		
		// Read the gamepad
		GamepadValue = Gamepad_Read(0);		
		// player controls
                //right, left, up, down
		if(GamepadValue & GAMEPAD_DOWN)
		{
                       	pac_dir=3;
		}
		else if(GamepadValue & GAMEPAD_UP)
		{
				pac_dir=2;
		}
		else if(GamepadValue & GAMEPAD_LEFT)
		{
				pac_dir=1;
		}
		else if(GamepadValue & GAMEPAD_RIGHT)
		{
			    pac_dir=0;
		}

		//move pac and sees if it hits a wall
		j=move_pac(pac_dir);
		if(j>0 && (pac_dir_old != pac_dir))
		{
			pac_dir=pac_dir_old;
  		    j=move_pac(pac_dir);
		}
		else if(j==0) //doesn't hit any walls
		{
			if(pac_dir!=pac_dir_old)
				pac_tic=99;
		    //make sure we stay aligned
		    if(pac_dir==2 || pac_dir==3) //up or down
		    {
			 if((pac_x&0x07)>3)
		       pac_x+=8;
			 pac_x&=0xF8;
		    }
		    if(pac_dir==0 || pac_dir==1) //left or right
		    {
			 if((pac_y&0x07)>3)
		       pac_y+=8;
			 pac_y&=0xF8;
		    }
		}

		g_Sprites[0].Y=pac_y-2;
 		g_Sprites[0].X=pac_x-2;
		g_Sprites[0].X&=0xFF;
		g_Sprites[0].Y&=0xFF;
		//animate pac
		if(pac_tic>4)
		{
			pac_frame++;
			pac_frame&=3;
			//g_Sprites[0].PixelData = g_SpriteData + (9 <<8); //debug
			pac_tic=0;			
		}		
		j=(pac_animation[pac_frame+(pac_dir<<2)]);
		if(j>9)
			j=9;
                
		copy_sprites((g_PacSprites + (j<<8)), g_SpriteData);
		g_Sprites[0].PixelData = g_SpriteData;

                move_ghost(0); 
                move_ghost(1); 
                move_ghost(2); 
                move_ghost(3); 
		
		if(pac_ghost_hit()>0)
		{
			misc_timer=0;
			GameState=4;
		}
	}

}

void intro_screen()
{
    copy_font(0,0); //copy font tiles
    fill_screen(0); //clears the screen
    print_string(11,1,"XGS-PAC");
    print_string(10,15,"Hit Start");
    print_string(0,23,"JT Cook   www.avalondreams.com");

    ghost_dir[0]=0;
    ghost_frame[0]=0;
    copy_sprites(g_PacSprites + ((21-7)<<8) +((ghost_dir[0]<<1) + ghost_frame[0]<<8) + ((0<<3)<<8), g_SpriteData + (1<<8));
    g_Sprites[1].PixelData = g_SpriteData + (1<<8);
    g_Sprites[1].X=26+8;
    g_Sprites[1].Y=42;

    copy_sprites(g_PacSprites + ((21-7)<<8) +((ghost_dir[0]<<1) + ghost_frame[0]<<8) + ((1<<3)<<8), g_SpriteData + (2<<8));
    g_Sprites[2].PixelData = g_SpriteData + (3<<8);
    g_Sprites[2].X=26+8;
    g_Sprites[2].Y=58;

    copy_sprites(g_PacSprites + ((21-7)<<8) +((ghost_dir[0]<<1) + ghost_frame[0]<<8) + ((2<<3)<<8), g_SpriteData + (3<<8));
    g_Sprites[3].PixelData = g_SpriteData + (2<<8);
    g_Sprites[3].X=26+8;
    g_Sprites[3].Y=74;

    copy_sprites(g_PacSprites + ((21-7)<<8) +((ghost_dir[0]<<1) + ghost_frame[0]<<8) + ((3<<3)<<8), g_SpriteData + (4<<8));
    g_Sprites[4].PixelData = g_SpriteData + (4<<8);
    g_Sprites[4].X=26+8;
    g_Sprites[4].Y=90;

    print_string(7,4,  "Shadow .... Blinky");
    print_string(7,6,  "Speedy .... Pinky");
    print_string(7,8,  "Bashful ... Inky");
    print_string(7,10, "Pokey ..... Clyde");

    ghost_frame[0]=1;
    copy_sprites(g_PacSprites +((ghost_dir[0]<<1) + ghost_frame[0]<<8), g_SpriteData + (0<<8));
    g_Sprites[0].PixelData = g_SpriteData + (0<<8);
    g_Sprites[0].X=26+8;
    g_Sprites[0].Y=160;

    pac_dir=1;
    pac_x=26+8;
    pac_y=160;

    pac_lives=3; // starting lives
}

void reset_maze()
{
//copy maze
    int i, mapx=0, map_offset=0;
    fill_screen(0); //clears the screen
    change_maze(Maze_Color,New_Maze_Color);
    total_dots=0; //clear pellet counter
    for(i=0;i<21*(24);i++)
    {
	   g_TileMap[map_offset+mapx]=pac_maze[i];
	   //count up total dots that need to be eaten
	   if(pac_maze[i]==1 || pac_maze[i]==2)
	      total_dots++;
	   mapx++;
	   if(mapx>20)
           {
		mapx=0;
		map_offset+=SCREEN_TILE_MAP_WIDTH;
	   }
    }
}

//draw lives remaining
void draw_lives()
{
 int i;
 for(i=0;i<6;i++)
 {
  if(i+1<=pac_lives)
   g_TileMap[((15)*SCREEN_TILE_MAP_WIDTH)+22+i]=2;
  else
   g_TileMap[((15)*SCREEN_TILE_MAP_WIDTH)+22+i]=0;
 }
}

void reset_characters()
{
//reset Pacman, all the ghosts (after death, new game, new level)
		int j;
		pac_x =95;
		pac_y =128+32;
                pac_x_old=pac_x;
		pac_y_old=pac_y;
		g_Sprites[0].Y=pac_y-2;
		g_Sprites[0].X=pac_x-2;
		pac_dir=1;
		pac_frame=0;
		pac_dir_old=pac_dir;
		j=(pac_animation[pac_frame+(pac_dir<<2)]);
		if(j>9)
			j=9;
                copy_sprites(g_PacSprites + (j<<8), g_SpriteData);
		g_Sprites[0].PixelData = g_SpriteData;

                //setup ghosts
		ghost_x[0]=95;
		ghost_y[0]=80;
		ghost_dir[0]=RAND_RANGE(0,3);
		g_Sprites[1].X=ghost_x[0]-2;
		g_Sprites[1].Y=ghost_y[0]-2;
		ghost_x[1]=95;
		ghost_y[1]=80;
		ghost_dir[1]=RAND_RANGE(0,3);
		copy_sprites(g_PacSprites + ((21-7)<<8) +((ghost_dir[0]<<1) + ghost_frame[0]<<8) + ((0<<3)<<8), g_SpriteData + (1<<8));
		g_Sprites[1].PixelData = g_SpriteData + (1<<8);
		g_Sprites[2].X=ghost_x[1]-2;
		g_Sprites[2].Y=ghost_y[1]-2;
		ghost_x[2]=95-16;
		ghost_y[2]=80;
		ghost_dir[2]=RAND_RANGE(0,3);
                copy_sprites(g_PacSprites + ((21-7)<<8) +((ghost_dir[1]<<1) + ghost_frame[1]<<8) + ((1<<3)<<8), g_SpriteData + (2<<8));
		g_Sprites[2].PixelData = g_SpriteData + (2<<8);
		g_Sprites[3].X=ghost_x[2]-2;
		g_Sprites[3].Y=ghost_y[2]-2;
		ghost_x[3]=95+16;
		ghost_y[3]=80;
		ghost_dir[3]=RAND_RANGE(0,3);
		copy_sprites(g_PacSprites + ((21-7)<<8) +((ghost_dir[2]<<1) + ghost_frame[2]<<8) + ((2<<3)<<8), g_SpriteData + (3<<8));
		g_Sprites[3].PixelData = g_SpriteData + (3<<8);
		g_Sprites[4].X=ghost_x[3]-2;
		g_Sprites[4].Y=ghost_y[3]-2;		
		copy_sprites(g_PacSprites + ((21-7)<<8) +((ghost_dir[3]<<1) + ghost_frame[3]<<8) + ((3<<3)<<8), g_SpriteData + (4<<8));
		g_Sprites[4].PixelData = g_SpriteData + (4<<8);

		draw_lives();
}

unsigned char check_ghost_direction(unsigned char g_number)
{
   unsigned char wall_check1=0, wall_check2, wall_check=0;
   switch(ghost_dir[g_number])
   {
	case 0: // right (check up and down)
          //check up
          wall_check1=check_wall(ghost_x[g_number]+2,ghost_y[g_number]+2-4,ghost_x[g_number]+7-2,ghost_y[g_number]+7-2-4);
	  //check down
          wall_check2=check_wall(ghost_x[g_number]+2,ghost_y[g_number]+2+4,ghost_x[g_number]+7-2,ghost_y[g_number]+7-2+4);
	break;
	case 1: // left (check up and down)
          //check up
          wall_check1=check_wall(ghost_x[g_number]+2,ghost_y[g_number]+2-4,ghost_x[g_number]+7-2,ghost_y[g_number]+7-2-4);
	  //check down
          wall_check2=check_wall(ghost_x[g_number]+2,ghost_y[g_number]+2+4,ghost_x[g_number]+7-2,ghost_y[g_number]+7-2+4);
	break;
	case 2: // up (check left and right)
          //check left
          wall_check1=check_wall(ghost_x[g_number]+2-4,ghost_y[g_number]+2,ghost_x[g_number]+7-2-4,ghost_y[g_number]+7-2);
	  //check right
          wall_check2=check_wall(ghost_x[g_number]+2+4,ghost_y[g_number]+2,ghost_x[g_number]+7-2-4,ghost_y[g_number]+7-2);
	break;
	case 3: // left (check left and right)
          //check left
          wall_check1=check_wall(ghost_x[g_number]+2-4,ghost_y[g_number]+2,ghost_x[g_number]+7-2-4,ghost_y[g_number]+7-2);
	  //check right
          wall_check2=check_wall(ghost_x[g_number]+2+4,ghost_y[g_number]+2,ghost_x[g_number]+7-2-4,ghost_y[g_number]+7-2);
	break;
   }   
   if(wall_check1==0)
      wall_check|=1; //mark wall check 1
   if (wall_check2==0)
      wall_check|=2; //mark wall check 2

 return(wall_check);
}

unsigned char check_random_dir(unsigned char dir1, unsigned char dir2, unsigned char dir3)
{
 //bit 1 = right, bit 2 = left, bit 3 = up, bit 4 = down
 unsigned char dir_value;
 //only 2 directions
 if(dir3>3)
 {
   dir_value=RAND_RANGE(0,1);
   if(dir_value==0)
     return(dir1);
   else
     return(dir2);
 }
 else
 {
   dir_value=RAND_RANGE(0,2);
   if(dir_value==0)
     return(dir1);
   else if(dir_value==1)
     return(dir2);
   else
     return(dir3);
 }
}

void move_ghost(unsigned char g_number)
{
 char wall_check, ghost_dir_old;
//ghost_x[4], ghost_y[4], ghost_x_old[4], ghost_y_old[4], ghost_dir[4], ghost_tic[4], ghost_frame[4];
 ghost_x_old[g_number]=ghost_x[g_number];
 ghost_y_old[g_number]=ghost_y[g_number];
 ghost_dir_old=ghost_dir[g_number];
 switch(ghost_dir[g_number])
 {
    case 0: //right
     ghost_x[g_number]++;
    break;
    case 1: //left
     ghost_x[g_number]--;
    break;
    case 2: //up
     ghost_y[g_number]--;
    break;
    case 3: //down
     ghost_y[g_number]++;
    break;
 }
 //check screen border for tunnel
 if(ghost_x[g_number]>220)
   ghost_x[g_number]=180;
 else if(ghost_x[g_number]>180)
   ghost_x[g_number]=0;

 //if ghost hits a wall, change direction
 if(check_wall(ghost_x[g_number]+1,ghost_y[g_number]+1,ghost_x[g_number]+7-1,ghost_y[g_number]+7-1)>0)
 {
   ghost_x[g_number]=ghost_x_old[g_number];
   ghost_y[g_number]=ghost_y_old[g_number];
   wall_check=check_ghost_direction(g_number);
   switch(ghost_dir[g_number])
   {
//x1 = RAND_RANGE(0,(SCREEN_WIDTH/2)-1);		// Random X in half the screen
	case 0: //right
	  if((wall_check&3) == 3) //both up and down are free (randomly select)
	    ghost_dir[g_number]=RAND_RANGE(2,3);
	  else if((wall_check&1) == 1) //up is free
	    ghost_dir[g_number]=2;
	  else if((wall_check&2) == 2) //down is free
	    ghost_dir[g_number]=3;
	  else //backtrack
	    ghost_dir[g_number]=1; 
	break;
	case 1: //left
	  if((wall_check&3) == 3) //both up and down are free (randomly select)
	    ghost_dir[g_number]=RAND_RANGE(2,3);
	  else if((wall_check&1) == 1) //up is free
	    ghost_dir[g_number]=2;
	  else if((wall_check&2) == 2) //down is free
	    ghost_dir[g_number]=3;
	  else //backtrack
	    ghost_dir[g_number]=0; 
	break;
	case 2: //up
	  if((wall_check&3) == 3) //both up and down are free (randomly select)
	    ghost_dir[g_number]=RAND_RANGE(0,1);
	  else if((wall_check&1) == 1) //left is free
	    ghost_dir[g_number]=1;
	  else if((wall_check&2) == 2) //right is free
	    ghost_dir[g_number]=0;
	  else //backtrack
	    ghost_dir[g_number]=3; 
	break;
	case 3: //down
	  if((wall_check&3) == 3) //both up and down are free (randomly select)
	    ghost_dir[g_number]=RAND_RANGE(0,1);
	  else if((wall_check&1) == 1) //left is free
	    ghost_dir[g_number]=1;
	  else if((wall_check&2) == 2) //right is free
	    ghost_dir[g_number]=0;
	  else //backtrack
	    ghost_dir[g_number]=2; 
	break;
   }
   if(ghost_dir[g_number]==2 || ghost_dir[g_number]==3) //up or down
   {
	if((ghost_x[g_number]&0x07)>3)
		ghost_x[g_number]+=8;
	ghost_x[g_number]&=0xF8;
   }
   if(ghost_dir[g_number]==0 || ghost_dir[g_number]==1) //left or right
   {
	if((ghost_y[g_number]&0x07)>3)
		ghost_y[g_number]+=8;
	ghost_y[g_number]&=0xF8;
   }
 }
 //check to see if there are any open passages
 else if(ghost_hall_ctr[g_number]>11)
 {
   wall_check=check_ghost_direction(g_number);
   switch(ghost_dir[g_number])
   {
	case 0: //right
	  if((wall_check&3) == 3) //both up and down are free (randomly select)
 	    ghost_dir[g_number]=check_random_dir(0, 2, 3);
	  else if((wall_check&1) == 1) //up is free
 	    ghost_dir[g_number]=check_random_dir(0, 2, 9);
	  else if((wall_check&2) == 2) //down is free
 	    ghost_dir[g_number]=check_random_dir(0, 3, 9);
	break;
	case 1: //left
	  if((wall_check&3) == 3) //both up and down are free (randomly select)
 	    ghost_dir[g_number]=check_random_dir(1, 2, 3);
	  else if((wall_check&1) == 1) //up is free
 	    ghost_dir[g_number]=check_random_dir(1, 2, 9);
	  else if((wall_check&2) == 2) //down is free
 	    ghost_dir[g_number]=check_random_dir(1, 3, 9);
	break;
	case 2: //up
	  if((wall_check&3) == 3) //both up and down are free (randomly select)
 	    ghost_dir[g_number]=check_random_dir(2, 0, 1);
	  else if((wall_check&1) == 1) //left is free
 	    ghost_dir[g_number]=check_random_dir(2, 1, 9);
	  else if((wall_check&2) == 2) //right is free
 	    ghost_dir[g_number]=check_random_dir(2, 0, 9);
	break;
	case 3: //down
	  if((wall_check&3) == 3) //both up and down are free (randomly select)
 	    ghost_dir[g_number]=check_random_dir(3, 0, 1);
	  else if((wall_check&1) == 1) //left is free
 	    ghost_dir[g_number]=check_random_dir(3, 1, 9);
	  else if((wall_check&2) == 2) //right is free
 	    ghost_dir[g_number]=check_random_dir(3, 0, 9);
	break;

   }

   if(ghost_dir[g_number]==2 || ghost_dir[g_number]==3) //up or down
   {
	if((ghost_x[g_number]&0x07)>3)
		ghost_x[g_number]+=8;
	ghost_x[g_number]&=0xF8;
   }
   if(ghost_dir[g_number]==0 || ghost_dir[g_number]==1) //left or right
   {
	if((ghost_y[g_number]&0x07)>3)
		ghost_y[g_number]+=8;
	ghost_y[g_number]&=0xF8;
   }
   ghost_hall_ctr[g_number]=0;
 }
 else
  ghost_hall_ctr[g_number]++;
 g_Sprites[1+g_number].X=ghost_x[g_number]-2;
 g_Sprites[1+g_number].Y=ghost_y[g_number]-2;

 ghost_tic[g_number]++;
 if(ghost_tic[g_number]>8)
 {
   ghost_tic[g_number]=0;
   ghost_frame[g_number]^=1;
   //update graphic if frame changes
   copy_sprites(g_PacSprites + ((21-7)<<8) +((ghost_dir[g_number]<<1) + ghost_frame[g_number]<<8) + ((g_number<<3)<<8), g_SpriteData + ((g_number+1)<<8) );
 }

//update graphic if ghost changes direction
 if(ghost_dir_old!=ghost_dir[g_number])
   copy_sprites(g_PacSprites + ((21-7)<<8) +((ghost_dir[g_number]<<1) + ghost_frame[g_number]<<8) + ((g_number<<3)<<8), g_SpriteData + ((g_number+1)<<8) );


}

//////////////////////////////////////////////
//check hit detection between pac and ghost
int pac_ghost_hit() 
{
 int gnumber;

 for(gnumber=0;gnumber<4;gnumber++)
 {
  if((pac_x+2<=ghost_x[gnumber]+10) && (pac_x+10>=ghost_x[gnumber]+2) &&
     (pac_y+2<=ghost_y[gnumber]+10) && (pac_y+10>=ghost_y[gnumber]+2))
	return(gnumber+1); //return ghost that was hit
 }

 return(0); //no hit
}

//////////////////////////////////////////////
// move pac on map
int move_pac(int p_dir)
{
		int j;
		pac_x_old=pac_x;
		pac_y_old=pac_y;

		//move pac
		if(p_dir==0) //right
		{
				pac_x++;
				j=check_wall(pac_x, pac_y+2, pac_x+7, pac_y+7-2);
		}
		else if(p_dir==1) //left
		{
				pac_x--;
				j=check_wall(pac_x, pac_y+2, pac_x+7, pac_y+7-2);
		}
		else if(p_dir==2) //up
		{
				pac_y--;
				j=check_wall(pac_x+2, pac_y, pac_x+7-2, pac_y+7);
		}
		else if(p_dir==3) //down
		{
				pac_y++;
				j=check_wall(pac_x+2, pac_y, pac_x+7-2, pac_y+7);
		}
		//check colision detection
		if(j>0)
		{
			  pac_x=pac_x_old;
			  pac_y=pac_y_old;
		}
		else
                {
			pac_tic++;
			//check dots
			check_dots(pac_x, pac_y);
		}
		 //check screen limits for tunnels
		 if(pac_x>220)
			pac_x=180;
		 else if(pac_x>180)
		    pac_x=0;
		
		return(j);		
}

//////////////////////////////////////////////
// Check colision detection
int check_wall(int x, int y,int xx,int yy)
{
 #define x_limit_max 233
 #define x_limit_min 6
 int x1, x2, y1,y2, hit=0;
 x-=16;
 y-=16;
 if(x>x_limit_max)
   x=x_limit_max;
 if(y>191)
   y=191;
 xx-=16;
 yy-=16;
 if(xx>x_limit_max)
   xx=x_limit_max;
 if(yy>191)
   yy=191;

 if(x<x_limit_min)
    x=x_limit_min;
 if(xx<x_limit_min)
    xx=x_limit_min;
 x1=x;
 y1=y;
 x2=xx;
 y2=yy;
 x1>>=3;
 y1>>=3;
 x2>>=3;
 y2>>=3;
 hit=0;
 //upper left, bit 0
 if(g_TileMap[(y1*SCREEN_TILE_MAP_WIDTH)+x1]>2)
    hit|=1;
 //upper right, bit 1
 if(g_TileMap[(y1*SCREEN_TILE_MAP_WIDTH)+x2]>2)
    hit|=2;
 //lower left, bit 2
 if(g_TileMap[(y2*SCREEN_TILE_MAP_WIDTH)+x1]>2)
    hit|=4;
 //lower right, bit 3
 if(g_TileMap[(y2*SCREEN_TILE_MAP_WIDTH)+x2]>2)
    hit|=8;

 return(hit);
}

void check_dots(int x, int y)
{
 int tempx, tempy;
 x-=16;
 y-=16;
 tempx=x&7;
 tempy=y&7;
 if((tempx<3 || tempx>5) && (tempy<3 || tempy>5))
 {
  if(tempx>5)
     x+=8;
  if(tempy>5)
     y+=8;
  // check dot
  x>>=3;
  y>>=3;
  tempx=(y*SCREEN_TILE_MAP_WIDTH)+x;
  //check limits
//  if(tempx>(SCREEN_TILE_MAP_WIDTH * SCREEN_TILE_MAP_HEIGHT)-1)
//     tempx=(SCREEN_TILE_MAP_WIDTH * SCREEN_TILE_MAP_HEIGHT)-1;
  //check dot
  if(g_TileMap[tempx]==1)
  {
     //eat dot
     g_TileMap[tempx]=0;
     total_dots--;
  }
  //check power pellet
  else if(g_TileMap[tempx]==2)
  {
     //eat power pellet
     g_TileMap[tempx]=0;
     total_dots--;
  }
  //all gone
  if(total_dots==0)
  {
    GameState=2;
    misc_timer=0; 
  }
 }
}
///////////////////////////////////////////////////////////////
//What to do when you beat the maze and eat all the dots
void Beat_Level()
{
 //use the dot counter as a time
 total_dots++;
 if(total_dots>30)
 {
   misc_timer++;
   total_dots=0;
   pac_dir^=1;
   pac_dir&=1;
   if(pac_dir==1)
        //change the maze to white
        change_maze(New_Maze_Color, White_Maze);
   else
        //change the maze to blue
        change_maze(White_Maze, New_Maze_Color);

  if(misc_timer>6)
  {
   //make sure maze ends up blue
   change_maze(White_Maze, New_Maze_Color);
   GameState=3; 
   reset_maze();
   reset_characters();
   misc_timer=0;
  }
 }
}

//////////////////////////////////////////////////////////////
//screen helpers
void change_maze(unsigned char old_color, unsigned char new_color)
{
 unsigned char tiles, mul;
 unsigned int n=64*3;
 for(tiles=0;tiles<15;tiles++)
 {
  for(mul=0;mul<64;mul++)
  {
    if(g_TileData[n]==old_color)
       g_TileData[n]=new_color;
    n++;
  }
 }
}

//////////////////////////////////////////////////////////////
//screen helpers
void copy_sprites(char *source_sprite, char *dest_sprite)
{
 int cnt, n=0;
 char test_color;
 for(cnt=0;cnt<256;cnt++)
 {
   dest_sprite[n]=source_sprite[n];
/*
   if(source_sprite[n]>0xAF)
   {
	 //safe colors
     dest_sprite[n]=(source_sprite[n]&0xF) | 0xA0;	
   }
*/
   //dest_sprite[n]=0xFF;
   n++;
 }
}

void copy_font(int char_number, int char_data)
{
 //font_color, font_bg
 int n=0,n2=0, nx, ny, offset=8*48;
 unsigned char t_char;
 for(n=0;n<64;n++)
 {
  g_TileData[n2]=font_bg;
  n2++;
 }
 
 //numbers
 for(n=0;n<10;n++)
 {
  for(ny=0;ny<8;ny++)
  {
   t_char=font1bit[offset];
   offset++;
   for(nx=0;nx<8;nx++)
   {
    if(t_char & 0x80)
       g_TileData[n2]=font_color;
    else
       g_TileData[n2]=font_bg;
    t_char<<=1;
    n2++;
   }
  }
 }
 //letters
 offset=8*65;
 for(n=0;n<26;n++)
 {
  for(ny=0;ny<8;ny++)
  {
   t_char=font1bit[offset];
   offset++;
   for(nx=0;nx<8;nx++)
   {
    if(t_char & 0x80)
       g_TileData[n2]=font_color;
    else
       g_TileData[n2]=font_bg;
    t_char<<=1;
    n2++;
   }
  }
 }
  //period
  offset=8*46;
  for(ny=0;ny<8;ny++)
  {
   t_char=font1bit[offset];
   offset++;
   for(nx=0;nx<8;nx++)
   {
    if(t_char & 0x80)
       g_TileData[n2]=font_color;
    else
       g_TileData[n2]=font_bg;
    t_char<<=1;
    n2++;
   }
  }

}

//prints a string
void print_string(int x, int y, char *string)
{
 int n, offset, screen_ctr;
 offset=font_offset-font_start;
 screen_ctr=y*SCREEN_TILE_MAP_WIDTH+x;
 for(n=0;n<50;n++)
 {
   if(string[n]>=48 && string[n]<58)
   //make sure we are only printing characters that we have graphics for
   //if(string[n]>32 && string[n]<90)
    g_TileMap[screen_ctr]=string[n]+offset; //draw digit
   else if(string[n]>=65 && string[n]<90)
    g_TileMap[screen_ctr]=string[n]+offset-(65-58);
   else if(string[n]>=97 && string[n]<123)
    g_TileMap[screen_ctr]=string[n]+offset-(97-58);
   else if(string[n]==46)
    g_TileMap[screen_ctr]=string[n]+offset+38;
   else if(string[n]==0)
    return;
   screen_ctr++;
 }

}

